@@ -1,4 +1,4 @@
-/* @(#)sigdefs.h	1.1 97/05/25 Copyright 1997 J. Schilling */
+/* @(#)sigdefs.h	1.2 01/03/04 Copyright 1997 J. Schilling */
 /*
  *	Signal abstraction for BSD/SVR4 signals
  *
@@ -25,6 +25,9 @@
 
 #ifdef	SIGPAUSE	/* must be SVR4 */
 #define	signal		sigset
+#endif
+
+#ifdef	HAVE_SIGPROCMASK
 #define	block_sigs(a)	{ \
 				sigset_t	new;	\
 							\
@@ -39,10 +42,21 @@
 				sigprocmask(SIG_UNBLOCK, &new, NULL);\
 			}
 #define	restore_sigs(a)	sigprocmask(SIG_SETMASK, &a, 0);
-#else
+
+#else	/* !HAVE_SIGPROCMASK */
+
 #define	sigset_t	int
 #define	block_sigs(a)	a = sigblock(0xFFFFFFFF)
 #define	restore_sigs(a)	sigsetmask(a);
-#endif
+#define	unblock_sig(s)	{ \
+				int	old, new;	\
+							\
+				block_sigs(old);	\
+				new = sigmask(s);	\
+				new = old & ~new;	\
+				sigsetmask(new);	\
+			}
+
+#endif	/* HAVE_SIGPROCMASK */
 
 #endif	/* _SIGDEFS_H */
