@@ -1,7 +1,7 @@
-/* @(#)diskfmt.c	1.5 98/06/01 Copyright 1988 J. Schilling */
+/* @(#)diskfmt.c	1.15 01/02/23 Copyright 1988 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)diskfmt.c	1.5 98/06/01 Copyright 1988 J. Schilling";
+	"@(#)diskfmt.c	1.15 01/02/23 Copyright 1988 J. Schilling";
 #endif
 /*
  *	Format SCSI disks
@@ -24,6 +24,7 @@ static	char sccsid[] =
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <mconfig.h>
 #include <stdio.h>
 #include <standard.h>
 #include <signal.h>
@@ -33,13 +34,15 @@ static	char sccsid[] =
 #include <waitdefs.h>
 #include <timedefs.h>
 #include <strdefs.h>
+#include <schily.h>
 
 #include <dsklabel.h>
 
-#include <scgio.h>
+#include <scg/scgcmd.h>
+#include <scg/scsireg.h>
+#include <scg/scsidefs.h>
+#include <scg/scsitransp.h>
 
-#include "scsireg.h"
-#include "scsidefs.h"
 #include "scsicmds.h"
 
 #include "defect.h"
@@ -47,19 +50,12 @@ static	char sccsid[] =
 
 #define	strindex(s1, s2)	strstr((s2), (s1))
 
-extern	int	dev;
-
 extern	struct timeval	starttime;
 
 extern	char	*Sbuf;
 extern	long	Sbufsize;
-extern	int	scsibus;
-extern	int	target;
-extern	int	lun;
 extern	int	xdebug;
 extern	int	debug;
-extern	int	silent;
-extern	int	verbose;
 extern	int	force;
 
 extern	int	wrveri;
@@ -73,11 +69,7 @@ extern	int	save_mp;
 extern	int	defmodes;
 extern	int	no_heuristic_defaults;
 
-extern	struct	scg_cmd	scmd;
-
 	struct scsi_format_data	fmt;
-extern	struct scsi_capacity	cap;
-extern	struct scsi_inquiry	inq;
 
 extern	int	Prpart;
 extern	int	label;
@@ -94,51 +86,52 @@ extern	struct	dk_label	*d_label;
 
 extern	defect			def;
 
-EXPORT	int	printgeom		__PR((int current));
-EXPORT	void	testformat		__PR((struct disk *dp));
+EXPORT	int	printgeom		__PR((SCSI *scgp, int current));
+EXPORT	void	testformat		__PR((SCSI *scgp, struct disk *dp));
 LOCAL	void	print_diskgeom		__PR((struct disk *dp));
-EXPORT	int	Adaptec4000		__PR((void));
-LOCAL	void	get_Adaptec_defaults	__PR((struct disk *dp));
-EXPORT	int	Emulex_MD21		__PR((void));
-EXPORT	void	get_defaults		__PR((struct disk *dp));
-LOCAL	void	get_proto_defaults	__PR((struct disk *dp, struct disk *xp));
-LOCAL	void	get_Emulex_defaults	__PR((struct disk *dp));
-LOCAL	void	get_sony_defaults	__PR((struct disk *dp));
+EXPORT	int	Adaptec4000		__PR((SCSI *scgp));
+LOCAL	void	get_Adaptec_defaults	__PR((SCSI *scgp, struct disk *dp));
+EXPORT	int	Emulex_MD21		__PR((SCSI *scgp));
+EXPORT	void	get_defaults		__PR((SCSI *scgp, struct disk *dp));
+LOCAL	void	get_proto_defaults	__PR((SCSI *scgp, struct disk *dp, struct disk *xp));
+LOCAL	void	get_Emulex_defaults	__PR((SCSI *scgp, struct disk *dp));
+LOCAL	void	get_sony_defaults	__PR((SCSI *scgp, struct disk *dp));
 LOCAL	void	get_general_defaults	__PR((struct disk *dp));
-EXPORT	void	get_lgeom_defaults	__PR((struct disk *dp));
-LOCAL	void	get_missing_defaults	__PR((struct disk *dp));
+EXPORT	void	get_lgeom_defaults	__PR((SCSI *scgp, struct disk *dp));
+LOCAL	void	get_missing_defaults	__PR((SCSI *scgp, struct disk *dp));
 LOCAL	BOOL	confirmformat		__PR((void));
 LOCAL	void	sigalrm			__PR((int sig));
 LOCAL	int	prpercent		__PR((long ftim));
-LOCAL	int	format_disk		__PR((struct disk *dp, int clear_gdl));
-EXPORT	int	reformat_disk		__PR((struct disk *dp));
-EXPORT	int	acb_format_disk		__PR((struct disk *dp, int clear_gdl));
-LOCAL	void	prconfig		__PR((struct disk *dp, struct disk *xp));
+LOCAL	int	format_disk		__PR((SCSI *scgp, struct disk *dp, int clear_gdl));
+EXPORT	int	reformat_disk		__PR((SCSI *scgp, struct disk *dp));
+EXPORT	int	acb_format_disk		__PR((SCSI *scgp, struct disk *dp, int clear_gdl));
+LOCAL	void	prconfig		__PR((SCSI *scgp, struct disk *dp, struct disk *xp));
 
 EXPORT int
-printgeom(current)
+printgeom(scgp, current)
+	SCSI	*scgp;
 	int	current;
 {
 	u_char	mode[0x100];
 	u_char	*p;
 	u_char	*ep;
 
-	silent++;
-	getdev(FALSE);
+	scgp->silent++;
+	getdev(scgp, FALSE);
 
 	/* XXX Quick and dirty, musz verallgemeinert werden !!! */
 
-	(void)unit_ready();
-	silent--;
+	(void)unit_ready(scgp);
+	scgp->silent--;
 
 	fillbytes(mode, sizeof(mode), '\0');
-	if (mode_sense(mode, 0xFF, 0x3F, current?0:2) < 0) {/* All Pages */
-		if (mode_sense(mode, 0xFF, 0, 0) < 0) /* VU (block desc) */
+	if (mode_sense(scgp, mode, 0xFF, 0x3F, current?0:2) < 0) {/* All Pages */
+		if (mode_sense(scgp, mode, 0xFF, 0, 0) < 0) /* VU (block desc) */
 			return (-1);
 	}
 
-	if (verbose)
-		prbytes("Mode Sense Data", mode, 0xFF - scmd.resid);
+	if (scgp->verbose)
+		prbytes("Mode Sense Data", mode, 0xFF - scg_getresid(scgp));
 
 	ep = mode+mode[0];	/* Points to last byte of data */
 	p = &mode[4];
@@ -152,24 +145,24 @@ printgeom(current)
 
 	if (mode[3] == 8) {
 		printf("Density: 0x%x\n", mode[4]);
-		printf("Blocks:  %ld\n", a_to_3_byte(&mode[5]));
-		printf("Blocklen:%ld\n", a_to_3_byte(&mode[9]));
+		printf("Blocks:  %ld\n", a_to_u_3_byte(&mode[5]));
+		printf("Blocklen:%ld\n", a_to_u_3_byte(&mode[9]));
 	}
 	p = &mode[4];
 	p += mode[3];
 	while (p < ep) {
 		if ((*p&0x3F) == 0x03) {
-			printf("Tr/zone: %d\n", a_to_u_short(&p[2]));
-			printf("As/zone: %d\n", a_to_u_short(&p[4]));
-			printf("At/zone: %d\n", a_to_u_short(&p[6]));
-			printf("At/vol:  %d\n", a_to_u_short(&p[8]));
-			printf("Nsect:   %d\n", a_to_u_short(&p[10]));
-			printf("Psecsize:%d\n", a_to_u_short(&p[12]));
-			printf("Tr skew: %d\n", a_to_u_short(&p[16]));
-			printf("Cy skew: %d\n", a_to_u_short(&p[18]));
+			printf("Tr/zone: %d\n", a_to_u_2_byte(&p[2]));
+			printf("As/zone: %d\n", a_to_u_2_byte(&p[4]));
+			printf("At/zone: %d\n", a_to_u_2_byte(&p[6]));
+			printf("At/vol:  %d\n", a_to_u_2_byte(&p[8]));
+			printf("Nsect:   %d\n", a_to_u_2_byte(&p[10]));
+			printf("Psecsize:%d\n", a_to_u_2_byte(&p[12]));
+			printf("Tr skew: %d\n", a_to_u_2_byte(&p[16]));
+			printf("Cy skew: %d\n", a_to_u_2_byte(&p[18]));
 		}
 		if ((*p&0x3F) == 0x04) {
-			printf("Ncyl:    %ld\n", a_to_3_byte(&p[2]));
+			printf("Ncyl:    %ld\n", a_to_u_3_byte(&p[2]));
 			printf("Nhead:   %d\n", p[5]);
 		}
 		p += p[1]+2;
@@ -178,23 +171,24 @@ printgeom(current)
 }
 
 EXPORT void
-testformat(dp)
+testformat(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
-	silent++;
-	if (read_capacity() >= 0) {
+	scgp->silent++;
+	if (read_capacity(scgp) >= 0) {
 		dp->formatted =
-				read_disk_label((struct dk_label *)Sbuf, 0L);
+				read_disk_label(scgp, (struct dk_label *)Sbuf, 0L);
 		/*
 		 * XXX check if we might get problems.
 		 */
-		if (dp->capacity != (cap.c_baddr + 1))
+		if (dp->capacity != (scgp->cap->c_baddr + 1))
 			printf("WARNING: cap: %ld baddr+1: %ld\n",
-					dp->capacity, cap.c_baddr + 1);
+					dp->capacity, (long)scgp->cap->c_baddr + 1);
 
-		dp->capacity = dp->cur_capacity = cap.c_baddr + 1;
+		dp->capacity = dp->cur_capacity = scgp->cap->c_baddr + 1;
 	}
-	silent--;
+	scgp->silent--;
 	printf("Disk %sformatted, %sLabel found.\n",
 				dp->formatted < 0 ? "un":"",
 				dp->formatted > 0 ? "":"no ");
@@ -219,43 +213,44 @@ print_diskgeom(dp)
 }
 
 EXPORT int
-Adaptec4000()
+Adaptec4000(scgp)
+	SCSI	*scgp;
 {
 	struct disk	*dp = &cur_disk;
 
-	testformat(dp);		/* test if disk is formatted */
+	testformat(scgp, dp);		/* test if disk is formatted */
 
 	if (dp->formatted > 0)	/* Sonst sind die Werte sinnlos */
-		get_acb4000defaults(dp);
+		get_acb4000defaults(scgp, dp);
 
-	get_ext_diskdata(inq.vendor_info, dp);
+	get_ext_diskdata(scgp, scgp->inq->vendor_info, dp);
 
 	if (!autoformat) {	/* XXX */
-		read_primary_label(dp);
+		read_primary_label(scgp, dp);
 		if (dp->labelread <= 0)
 			printf("No Label: Defaulting to Bull D585\n\n");
 	} else {
-		get_default_partition(dp);
+		get_default_partition(scgp, dp);
 	}
 
 	if (!no_heuristic_defaults)
-	 	get_Adaptec_defaults(dp);
+	 	get_Adaptec_defaults(scgp, dp);
 
-	get_missing_defaults(dp);
+	get_missing_defaults(scgp, dp);
 	get_general_defaults(dp);
 
 	if (dp->formatted > 0 && !yes("Ignore old defect List? "))
-		read_def_blk();
+		read_def_blk(scgp);
 	edit_def_blk();
 
 	print_diskgeom(dp);
 
 	if (!autoformat)
-		select_parameters(dp);
+		select_parameters(scgp, dp);
 
-	setlabel_from_val(dp, d_label);
+	setlabel_from_val(scgp, dp, d_label);
 	if (Prpart) {
-		prconfig(dp, (struct disk *)0);
+		prconfig(scgp, dp, (struct disk *)0);
 		/* NOTREACHED */
 	}
 	if (label)
@@ -264,8 +259,8 @@ Adaptec4000()
 	if (!yes("Set mode pages (needed for format)? "))
 		return (TRUE);
 
-	set_acb4000params(dp);
-	ext_modeselect(dp);
+	set_acb4000params(scgp, dp);
+	ext_modeselect(scgp, dp);
 
 	if (setmodes)
 		return(TRUE);
@@ -279,8 +274,8 @@ Adaptec4000()
 	prdate();
 	getstarttime();
 
-	if (unit_ready())
-		return (acb_format_disk(dp, TRUE));
+	if (unit_ready(scgp))
+		return (acb_format_disk(scgp, dp, TRUE));
 	return (FALSE);
 }
 
@@ -292,7 +287,8 @@ Adaptec4000()
 +---------------------------------------------------------------------------*/
 
 LOCAL void
-get_Adaptec_defaults(dp)
+get_Adaptec_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	if (dp->nhead < 0)
@@ -311,7 +307,7 @@ get_Adaptec_defaults(dp)
 	if (dp->lncyl < 0)
 		dp->lncyl	= dp->pcyl - dp->lacyl;
 	if (dp->spt < 0) {
-		if (dev == DEV_ACB4070)
+		if (scgp->dev == DEV_ACB4070)
 			dp->spt	= 26;
 		else
 			dp->spt	= 17;
@@ -337,11 +333,12 @@ get_Adaptec_defaults(dp)
 		dp->gap1 = 0;
 	if (dp->gap2 < 0)
 		dp->gap2 = 0;
-	get_lgeom_defaults(dp);
+	get_lgeom_defaults(scgp, dp);
 }
 
 EXPORT int
-Emulex_MD21()
+Emulex_MD21(scgp)
+	SCSI	*scgp;
 {
 	struct disk	*dp = &cur_disk;
 	int	cdl = TRUE;
@@ -349,17 +346,17 @@ Emulex_MD21()
 	if(debug)
 		printf("int_cyl: %ld lncyl: %ld\n", dp->int_cyl,
 			dp->lncyl);
-	testformat(dp);		/* test if disk is formatted */
+	testformat(scgp, dp);		/* test if disk is formatted */
 
 	if (Prpart)
-		get_proto_defaults(dp, &alt_disk);
+		get_proto_defaults(scgp, dp, &alt_disk);
 	else
-		get_defaults(dp);
+		get_defaults(scgp, dp);
 	if(debug)
 		printf("int_cyl: %ld lncyl: %ld\n", dp->int_cyl,
 			dp->lncyl);
 
-	get_ext_diskdata(inq.vendor_info, dp);
+	get_ext_diskdata(scgp, scgp->inq->vendor_info, dp);
 /*printf("XXX: disk_type: %s flags: %X\n", dp->disk_type, dp->flags);*/
 
 
@@ -378,11 +375,11 @@ Emulex_MD21()
 		printf("Trying to match disk with current mode pages:\n");
 		defmodes = FALSE;
 		alt_disk.formatted = 1;
-		get_defaults(&alt_disk);
+		get_defaults(scgp, &alt_disk);
 		alt_disk.formatted = dp->formatted;
 		defmodes = odefmodes;
 
-		get_ext_diskdata(inq.vendor_info, &alt_disk);
+		get_ext_diskdata(scgp, scgp->inq->vendor_info, &alt_disk);
 		alt_disk.capacity = dp->capacity;
 		alt_disk.cur_capacity = dp->cur_capacity;
 		if (alt_disk.disk_type)
@@ -395,27 +392,27 @@ Emulex_MD21()
 			dp->lncyl);
 
 	if (!autoformat) {	/* XXX */
-		read_primary_label(dp);
+		read_primary_label(scgp, dp);
 		if (dp->labelread <= 0)
 			printf("No Label: Defaulting to Drive values\n\n");
 	if(debug)
 		printf("int_cyl: %ld lncyl: %ld\n", dp->int_cyl,
 			dp->lncyl);
 	} else {
-		get_default_partition(dp);
+		get_default_partition(scgp, dp);
 	}
 
 	if (!no_heuristic_defaults)
-		get_Emulex_defaults(dp);
+		get_Emulex_defaults(scgp, dp);
 
-	get_missing_defaults(dp);
+	get_missing_defaults(scgp, dp);
 	get_general_defaults(dp);
 
 	if(debug)
 		printf("int_cyl: %ld lncyl: %ld\n", dp->int_cyl,
 			dp->lncyl);
 
-	if (dev == DEV_SONY_SMO) {
+	if (scgp->dev == DEV_SONY_SMO) {
 		if (dp->interleave == 1)
 			dp->interleave = 0;
 	}
@@ -423,16 +420,16 @@ Emulex_MD21()
 	print_diskgeom(dp);
 
 	if (!autoformat)
-		select_parameters(dp);
+		select_parameters(scgp, dp);
 
-	setlabel_from_val(dp, d_label);
+	setlabel_from_val(scgp, dp, d_label);
 	if (debug && !Prpart)
 		prpartab(stdout, "", d_label);
 	if (Prpart) {
 		if (defmodes)
-			prconfig(dp, &alt_disk);
+			prconfig(scgp, dp, &alt_disk);
 		else
-			prconfig(&alt_disk, dp);
+			prconfig(scgp, &alt_disk, dp);
 		/* NOTREACHED */
 	}
 	if (label)
@@ -445,18 +442,18 @@ Emulex_MD21()
 	if (!yes("Set mode pages (needed for format)? "))
 		return (TRUE);
 
-	if (dev == DEV_SONY_SMO) {
+	if (scgp->dev == DEV_SONY_SMO) {
 		if (dp->fmt_mode == 3)
 			save_mp = 0;
 	}
-	set_format_params(dp);
-	set_geom(dp);
-	set_error_rec_params(dp);
-	set_disre_params(dp);
-	if (dev == DEV_SONY_SMO)
-		set_sony_params(dp);
-	set_common_control(dp);
-	ext_modeselect(dp);
+	set_format_params(scgp, dp);
+	set_geom(scgp, dp);
+	set_error_rec_params(scgp, dp);
+	set_disre_params(scgp, dp);
+	if (scgp->dev == DEV_SONY_SMO)
+		set_sony_params(scgp, dp);
+	set_common_control(scgp, dp);
+	ext_modeselect(scgp, dp);
 
 	if (setmodes)
 		return(TRUE);
@@ -470,24 +467,26 @@ Emulex_MD21()
 	prdate();
 	getstarttime();
 
-	if (dev == DEV_SONY_SMO || unit_ready())
-		return (format_disk(dp, cdl));
+	if (scgp->dev == DEV_SONY_SMO || unit_ready(scgp))
+		return (format_disk(scgp, dp, cdl));
 	return (FALSE);
 }
 
 
 EXPORT void
-get_defaults(dp)
+get_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
-	if (dev == DEV_SONY_SMO)
-		get_sony_defaults(dp);
+	if (scgp->dev == DEV_SONY_SMO)
+		get_sony_defaults(scgp, dp);
 	else
-		get_mode_defaults(dp);
+		get_mode_defaults(scgp, dp);
 }
 
 LOCAL void
-get_proto_defaults(dp, xp)
+get_proto_defaults(scgp, dp, xp)
+	SCSI		*scgp;
 	struct disk	*dp;	/* ptr to return main disk data */
 	struct disk	*xp;	/* ptr to return alt disk data */
 {
@@ -501,21 +500,21 @@ get_proto_defaults(dp, xp)
 	 * 	'xp' points to default disk data and 'dp' points to current data
 	 */
 	dp->formatted = 1;		/* use only defmodes in modes.c */
-	get_defaults(dp);
+	get_defaults(scgp, dp);
 
 	defmodes = !defmodes;
 	dp->formatted = 1;		/* use only defmodes in modes.c */
 	xp->formatted = 1;		/* use only defmodes in modes.c */
-	get_defaults(xp);
+	get_defaults(scgp, xp);
 
 	dp->formatted = formatted;
 	xp->formatted = formatted;
 	defmodes = odefmodes;
 
-	get_lgeom_defaults(xp);
+	get_lgeom_defaults(scgp, xp);
 	if (xp->lncyl < 0)
-		xp->lncyl = get_default_lncyl(xp);
-	get_missing_defaults(xp);
+		xp->lncyl = get_default_lncyl(scgp, xp);
+	get_missing_defaults(scgp, xp);
 	get_general_defaults(xp);
 	if (xp->cur_capacity < 0)
 		xp->cur_capacity = dp->cur_capacity;
@@ -528,14 +527,15 @@ get_proto_defaults(dp, xp)
 +---------------------------------------------------------------------------*/
 
 LOCAL void
-get_Emulex_defaults(dp)
+get_Emulex_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	if (dp->tpz < 0)
 		dp->tpz	= 1;
 	if (dp->atrk < 0 && dp->nhead > 0)
 		dp->atrk	= 2 * dp->nhead;
-	if (strindex("EMULEX", inq.info))
+	if (strindex("EMULEX", scgp->inq->info))
 		dp->int_cyl = 3;
 	else if (dp->int_cyl < 0)
 		dp->int_cyl = 0;
@@ -553,7 +553,7 @@ get_Emulex_defaults(dp)
 		dp->gap1 = 0;
 	if (dp->gap2 < 0)
 		dp->gap2 = 0;
-	get_lgeom_defaults(dp);
+	get_lgeom_defaults(scgp, dp);
 }
 
 
@@ -564,16 +564,17 @@ get_Emulex_defaults(dp)
 +---------------------------------------------------------------------------*/
 
 LOCAL void
-get_sony_defaults(dp)
+get_sony_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
-	silent++;
-	get_error_rec_defaults(dp);
-	get_disre_defaults(dp);
-	if (read_capacity() >= 0)
-		dp->secsize = cap.c_bsize;
-	get_sony_format_defaults(dp);
-	silent--;
+	scgp->silent++;
+	get_error_rec_defaults(scgp, dp);
+	get_disre_defaults(scgp, dp);
+	if (read_capacity(scgp) >= 0)
+		dp->secsize = scgp->cap->c_bsize;
+	get_sony_format_defaults(scgp, dp);
+	scgp->silent--;
 	if (no_heuristic_defaults)
 		return;
 	if (dp->nhead < 0)
@@ -614,7 +615,7 @@ get_sony_defaults(dp)
 		dp->def_lst_format = SC_DEF_PHYS;
 	if (dp->fmt_mode == 3)
 		save_mp = 0;
-	get_lgeom_defaults(dp);
+	get_lgeom_defaults(scgp, dp);
 	if (dp->lncyl < 0 && dp->pcyl > 0)	/*XXX hier ??*/
 		dp->lncyl	= dp->pcyl
 				- dp->atrk/dp->nhead
@@ -650,7 +651,8 @@ get_general_defaults(dp)
 }
 
 EXPORT void
-get_lgeom_defaults(dp)
+get_lgeom_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	if (dp->lhead < 0)
@@ -659,7 +661,7 @@ get_lgeom_defaults(dp)
 		dp->lspt = dp->spt;
 	if (dp->lacyl < 0)
 		dp->lacyl =
-			(old_acb(dev) || (dp->nhead == 1)) ? 2L : 1L;
+			(old_acb(scgp->dev) || (dp->nhead == 1)) ? 2L : 1L;
 	if (dp->lpcyl < 0 ||
 	   (dp->lpcyl != dp->pcyl && ((dp->flags & D_DISK_LPCYL) == 0))) {
 		/*
@@ -678,17 +680,18 @@ get_lgeom_defaults(dp)
 }
 
 LOCAL void
-get_missing_defaults(dp)
+get_missing_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	if (dp->rpm < 0) {
-		if (inq.data_format >= 2)
+		if (scgp->inq->data_format >= 2)
 			printf("Disk states to be SCSI-2 but really is not.\n");
 		printf("WARNING: disk rotation rate not known.\n");
 		if (!yes("Don't use 3600 as default? "))
 			dp->rpm = 3600;
 	}
-	if (!ccs(dev)) {
+	if (!is_ccs(scgp->dev)) {
 		if (dp->track_skew < 0)
 			dp->track_skew = 0;
 		if (dp->cyl_skew < 0)
@@ -756,7 +759,8 @@ LOCAL int prpercent(ftim)
 }
 
 LOCAL int
-format_disk(dp, clear_gdl)
+format_disk(scgp, dp, clear_gdl)
+	SCSI		*scgp;
 	struct disk	*dp;
 	int	clear_gdl;
 {
@@ -772,18 +776,18 @@ format_disk(dp, clear_gdl)
 		printf("No Format!!\n");
 		return (TRUE);
 	}
-	read_sinfo(dp, TRUE);
+	read_sinfo(scgp, dp, TRUE);
 	printf("Formatting ... ");flush();
 	pid = prpercent(dp->fmt_time);
 
 	block_sigs(oldmask);
-	if (format_unit(&fmt, 0, (int)dp->def_lst_format,
+	if (format_unit(scgp, &fmt, 0, (int)dp->def_lst_format,
 				disable_mdl, clear_gdl,
 				(int)dp->interleave,
 				(int)dp->fmt_pattern,
 				(int)dp->fmt_timeout) >= 0) {
 		format_done = TRUE;
-		if (rezero_unit() >= 0)
+		if (rezero_unit(scgp) >= 0)
 			ret = TRUE;
 	} else if (force) {
 		if (yes("Continue? "))
@@ -791,12 +795,12 @@ format_disk(dp, clear_gdl)
 	}
 	alarm(0);
 	printf("done.\n");
-	if (read_capacity() < 0)
+	if (read_capacity(scgp) < 0)
 		ret = FALSE;
-	write_sinfo(dp);
-	label_disk(dp);
-	convert_def_blk();
-	write_def_blk(TRUE);
+	write_sinfo(scgp, dp);
+	label_disk(scgp, dp);
+	convert_def_blk(scgp);
+	write_def_blk(scgp, TRUE);
 	restore_sigs(oldmask);
 	kill(pid, SIGKILL);
 	while (wait(0) > 0)
@@ -805,7 +809,8 @@ format_disk(dp, clear_gdl)
 }
 
 EXPORT int
-reformat_disk(dp)
+reformat_disk(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	BOOL	ret	= FALSE;
@@ -820,19 +825,19 @@ reformat_disk(dp)
 		printf("No Reformat!!\n");
 		return (TRUE);
 	}
-	read_sinfo(dp, TRUE);
+	read_sinfo(scgp, dp, TRUE);
 	printf("Reformatting ... ");flush();
 	getstarttime();
 	pid = prpercent(dp->fmt_time);
 
 	block_sigs(oldmask);
-	if (format_unit(&fmt, 0, (int)dp->def_lst_format,
+	if (format_unit(scgp, &fmt, 0, (int)dp->def_lst_format,
 				disable_mdl, FALSE,
 				(int)dp->interleave,
 				(int)dp->fmt_pattern,
 				(int)dp->fmt_timeout) >= 0) {
 		format_done = TRUE;
-		if (rezero_unit() >= 0)
+		if (rezero_unit(scgp) >= 0)
 			ret = TRUE;
 	} else if (force) {
 		if (yes("Continue? "))
@@ -840,12 +845,12 @@ reformat_disk(dp)
 	}
 	alarm(0);
 	printf("done.\n");
-	if (read_capacity() < 0)
+	if (read_capacity(scgp) < 0)
 		ret = FALSE;
-	write_sinfo(dp);
-	label_disk(dp);
-	convert_def_blk();
-	write_def_blk(TRUE);
+	write_sinfo(scgp, dp);
+	label_disk(scgp, dp);
+	convert_def_blk(scgp);
+	write_def_blk(scgp, TRUE);
 	restore_sigs(oldmask);
 	kill(pid, SIGKILL);
 	while (wait(0) > 0)
@@ -903,7 +908,8 @@ reformat_with_bad(dp)
 #endif
 
 EXPORT int
-acb_format_disk(dp, clear_gdl)
+acb_format_disk(scgp, dp, clear_gdl)
+	SCSI		*scgp;
 	struct disk	*dp;
 	int	clear_gdl;
 {
@@ -919,19 +925,19 @@ acb_format_disk(dp, clear_gdl)
 		printf("No Format!!\n");
 		return (TRUE);
 	}
-	read_sinfo(dp, TRUE);
+	read_sinfo(scgp, dp, TRUE);
 	printf("Formatting ... ");flush();
 	pid = prpercent(dp->fmt_time);
 
 	block_sigs(oldmask);
-	if (format_unit((struct scsi_format_data *)&def,
-			(int)a_to_u_short(&def.d_size)/sizeof(def.d_def[0]),
+	if (format_unit(scgp, (struct scsi_format_data *)&def,
+			(int)a_to_u_2_byte(&def.d_size)/sizeof(def.d_def[0]),
 			SC_DEF_BFI, disable_mdl, clear_gdl,
 				(int)dp->interleave,
 				(int)dp->fmt_pattern,
 				(int)dp->fmt_timeout) >= 0) {
 		format_done = TRUE;
-		if (rezero_unit() >= 0)
+		if (rezero_unit(scgp) >= 0)
 			ret = TRUE;
 	} else if (force) {
 		if (yes("Continue? "))
@@ -939,12 +945,12 @@ acb_format_disk(dp, clear_gdl)
 	}
 	alarm(0);
 	printf("done.\n");
-	if (read_capacity() < 0)
+	if (read_capacity(scgp) < 0)
 		ret = FALSE;
-	write_sinfo(dp);
-	label_disk(dp);
-	convert_def_blk();
-	write_def_blk(TRUE);
+	write_sinfo(scgp, dp);
+	label_disk(scgp, dp);
+	convert_def_blk(scgp);
+	write_def_blk(scgp, TRUE);
 	restore_sigs(oldmask);
 	kill(pid, SIGKILL);
 	while (wait(0) > 0)
@@ -953,7 +959,8 @@ acb_format_disk(dp, clear_gdl)
 }
 
 LOCAL void
-prconfig(dp, xp)
+prconfig(scgp, dp, xp)
+	SCSI		*scgp;
 	struct disk	*dp;	/* ptr to default data */
 	struct disk	*xp;	/* ptr to current data */
 {
@@ -1036,10 +1043,10 @@ prconfig(dp, xp)
 
 	if (xp && cur_match > tot_match) {
 		fprintf(f, "# current data\n");
-		prdisk(f, xp, &inq);
+		prdisk(f, xp, scgp->inq);
 		fprintf(f, "# default data\n");
 	}
-	prdisk(f, dp, &inq);
+	prdisk(f, dp, scgp->inq);
 	prpartab(f, dp->disk_type, d_label);
 	checklabel(dp, d_label, 0);
 	fclose(f);
