@@ -1,4 +1,4 @@
-/* @(#)dsklabel.h	1.2 98/05/31 Copyright 1997 J. Schilling */
+/* @(#)dsklabel.h	1.3 01/04/24 Copyright 1997 J. Schilling */
 /*
  * 	Definitions for disk labels
  *
@@ -23,22 +23,26 @@
 #ifndef	_DSKLABEL_H
 #define	_DSKLABEL_H
 
-#if (defined(sparc) || defined(mc68000)) && defined(sun)
-
-#ifndef i386
+#if	(defined(HAVE_SYS_DKIO_H) && defined(HAVE_SYS_DKLABEL_H)) || \
+	(defined(HAVE_SUN_DKIO_H) && defined(HAVE_SUN_DKLABEL_H))
 #define	HAVE_DKIO
 #endif
 
-#endif
-
 #ifdef	HAVE_DKIO
-#	ifdef	SVR4
+
+#	ifdef	HAVE_SYS_DKIO_H
 #		include <sys/dkio.h>
+#	endif
+#	ifdef	HAVE_SYS_DKLABEL_H
 #		include <sys/dklabel.h>
-#	else
+#	endif
+#	ifdef	HAVE_SUN_DKIO_H
 #		include <sun/dkio.h>
+#	endif
+#	ifdef	HAVE_SUN_DKLABEL_H
 #		include <sun/dklabel.h>
 #	endif
+
 #else
 #	include "sun_dkio.h"
 #	include "sun_dklabel.h"
