@@ -1,12 +1,12 @@
-/* @(#)fmt.c	1.60 98/06/19 Copyright 1988 J. Schilling */
+/* @(#)fmt.c	1.77 01/04/25 Copyright 1986-1991, 93-97, 2000-2001 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)fmt.c	1.60 98/06/19 Copyright 1988 J. Schilling";
+	"@(#)fmt.c	1.77 01/04/25 Copyright 1986-1991, 93-97, 2000-2001 J. Schilling";
 #endif
 /*
  *	Format & check/repair SCSI disks
  *
- *	Copyright (c) 1988 J. Schilling
+ *	Copyright (c) 1986-1991, 93-97, 2000-2001 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -24,27 +24,29 @@ static	char sccsid[] =
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <mconfig.h>
 #include <stdio.h>
 #include <standard.h>
 #include <signal.h>
 #include <stdxlib.h>
 #include <unixstd.h>
 #include <strdefs.h>
-
 #include <timedefs.h>
+#include <errno.h>
+#include <schily.h>
 
-#include "scgio.h"
+#include <scg/scgcmd.h>
+#include <scg/scsireg.h>
+#include <scg/scsidefs.h>
+#include <scg/scsitransp.h>
 
-#include "scsireg.h"
-#include "scsidefs.h"
-#include "scsitransp.h"
 #include "defect.h"
 #include "scsicmds.h"
 #include "fmt.h"
 
 #define	strindex(s1, s2)	strstr((s2), (s1))
 
-int	dev	= DEV_UNKNOWN;
+char	fmt_version[] = "3.5";
 
 long		thistime = 0;
 struct timeval	starttime;
@@ -52,14 +54,8 @@ struct timeval	stoptime;
 
 char	*Sbuf;
 long	Sbufsize;
-int	scsibus;
-int	target;
-int	lun;
-int	kdebug;
 int	xdebug;
 int	debug;
-int	silent;
-int	verbose;
 int	nomap;
 int	nowait;
 int	force;
@@ -71,12 +67,6 @@ int	no_heuristic_defaults;
 int	scsi_compliant;
 int	ign_not_found;
 
-struct	scg_cmd	scmd;
-
-struct	scsi_format_data fmt;
-struct	scsi_capacity cap;
-struct	scsi_inquiry inq;
-
 int	Proto;
 int	Prpart;
 int	label;
@@ -92,8 +82,7 @@ int	refresh_only;
 int	wrveri;
 int	setmodes;
 int	modesel;
-int	deftimeout;
-int	noparity;
+LOCAL	int	deftimeout;
 /*#define	NVERI	5*/
 /*extern	int	n_test_patterns;*/
 /*#define	NWVERI	n_test_patterns*/
@@ -137,14 +126,14 @@ LOCAL	void	usage			__PR((int ret));
 LOCAL	void	xusage			__PR((int ret));
 EXPORT	int	main			__PR((int ac, char **av));
 LOCAL	void	print_product		__PR((struct scsi_inquiry *ip));
-LOCAL	void	select_target		__PR((void));
-LOCAL	void	select_unit		__PR((void));
-LOCAL	int	format_one		__PR((void));
-EXPORT	void	getdev			__PR((BOOL print));
-LOCAL	void	printdev		__PR((void));
-LOCAL	void	translate_lba		__PR((void));
-LOCAL	void	read_sector_header	__PR((void));
-LOCAL	void	esdi_command		__PR((void));
+LOCAL	void	select_target		__PR((SCSI *scgp));
+LOCAL	void	select_unit		__PR((SCSI *scgp));
+LOCAL	int	format_one		__PR((SCSI *scgp));
+EXPORT	void	getdev			__PR((SCSI *scgp, BOOL print));
+LOCAL	void	printdev		__PR((SCSI *scgp));
+LOCAL	void	translate_lba		__PR((SCSI *scgp));
+LOCAL	void	read_sector_header	__PR((SCSI *scgp));
+LOCAL	void	esdi_command		__PR((SCSI *scgp));
 LOCAL	long	estimate_format_time	__PR((struct disk *dp, int mult));
 EXPORT	void	estimate_times		__PR((struct disk *dp));
 EXPORT	void	print_fmt_time		__PR((struct disk *dp));
@@ -161,10 +150,12 @@ LOCAL void
 usage(ret)
 	int	ret;
 {
-	error("Usage:\tformat [options] target lun [scsibus]\n");
+	error("Usage:\tformat [options] [dev=scsidev]|[target lun [scsibus]]\n");
 	error("options:\n");
+	error("\tdev=target	SCSI target to use\n");
 	error("\t-help,-h\tprint this help\n");
 	error("\t-xhelp\t\tprint extended help\n");
+	error("\t-version\tPrint version number.\n");
 	error("\t-nomap\t\tDo not map SCSI adress to logical disk name\n");
 	error("\t-nowait\t\tDo not wait after formatting disk\n");
 	error("\t-force\t\tForce to continue at certain errors\n");
@@ -212,14 +203,15 @@ xusage(ret)
 	error("\tdebug=#,-d\tSet to # or increment misc debug level\n");
 	error("\tkdebug=#,kd=#\tKernel debug value for scg driver\n");
 	error("\txdebug=#,xd=#\tDebug level for eXternal disk database\n");
+	error("\t-verbose,-v\tincrement SCSI verbose level by one (outdated)\n");
+	error("\t-Verbose,-V\tincrement SCSI command transport verbose level by one\n");
 	error("\t-silent,-s\tdo not print status of failed SCSI commands\n");
-	error("\t-verbose,-v\tbe verbose for SCSI commands and parameters\n");
 	error("\t-defmodes\tGet default mode parameters from disk\n");
 	error("\t-no_defaults\tDo not set heuristic defaults\n");
 	error("\t-scsi_compliant\tBe as SCSI-compliant as possible\n");
 	error("\t-ign_not_found\tIgnore record not found errors on verify\n");
 	error("\ttimeout=#\tTimeout for SCSI commands (default %d)\n", deftimeout);
-	error("\tV=#\t\tNumber of verify loops (default %d)\n", NVERI);
+	error("\tVL=#\t\tNumber of verify loops (default %d)\n", NVERI);
 	error("\tRW=#\t\tNumber of random R/W loops\n");
 	error("\t\t\t(default Number of physical Sectors / 100)\n");
 	error("\tCveri=#\t\tNumber of blocks/verify\n");
@@ -249,10 +241,9 @@ xusage(ret)
 	exit(ret);
 }	
 
-char opts[] = "kdebug#,kd#,xdebug#,xd#,debug#,d+,silent,s,verbose,v,nomap,nowait,force,ask,noformat,smp,defmodes,no_defaults,scsi_compliant,ign_not_found,data*,Proto,Prpart,P,label,l,lname*,lproto*,tr,t,auto,a,dmdl,r,reassign,greassign,verify,repair,refresh_only,modes,setmodes,timeout#,noparity,wrveri,V#,Cveri#,C#,Vstart#L,Vend#L,CWveri#,CW#,maxbad#L,randrw,RW#L,S,ESDI#,inq,prgeom,prcurgeom,clearnull,readnull,damage,prdefect,seek,start,stop,nhead#l,lhead#l,pcyl#l,atrk#l,lacyl#l,lncyl#l,tpz#l,spt#l,lspt#l,aspz#l,secsize#l,rpm#l,trskew#l,cylskew#l,interlv#l,fmtpat#l,help,h,xhelp";
+char opts[] = "version,dev*,kdebug#,kd#,xdebug#,xd#,debug#,d+,silent,s,verbose+,v+,Verbose+,V+,nomap,nowait,force,ask,noformat,smp,defmodes,no_defaults,scsi_compliant,ign_not_found,data*,Proto,Prpart,P,label,l,lname*,lproto*,tr,t,auto,a,dmdl,r,reassign,greassign,verify,repair,refresh_only,modes,setmodes,timeout#,noparity,wrveri,VL#,Cveri#,C#,Vstart#L,Vend#L,CWveri#,CW#,maxbad#L,randrw,RW#L,S,ESDI#,inq,prgeom,prcurgeom,clearnull,readnull,damage,prdefect,seek,start,stop,nhead#l,lhead#l,pcyl#l,atrk#l,lacyl#l,lncyl#l,tpz#l,spt#l,lspt#l,aspz#l,secsize#l,rpm#l,trskew#l,cylskew#l,interlv#l,fmtpat#l,help,h,xhelp";
 
 #define	MAXVERI	100
-int	vlist[MAXVERI];
 
 EXPORT int
 main(ac, av)
@@ -263,6 +254,16 @@ main(ac, av)
 	int	fcount;
 	int	cac;
 	char	* const *cav;
+	int	scsibus	= -1;
+	int	target	= -1;
+	int	lun	= -1;
+	BOOL	prvers	= FALSE;
+	int	silent	= 0;
+	int	verbose	= 0;
+	int	kdebug	= 0;
+	int	noparity= 0;
+	SCSI	*scgp;
+	char	*dev = NULL;
 
 	save_args(ac, av);
 
@@ -274,9 +275,11 @@ main(ac, av)
 
 	if(getallargs(&cac, &cav, opts,
 #ifndef	lint		/* lint kann leider nur 52 args !!! */
+			&prvers, &dev,
 			&kdebug, &kdebug, &xdebug, &xdebug, &debug, &debug,
 			&silent, &silent,
 			&verbose, &verbose,
+			&verbose, &verbose,
 			&nomap,
 			&nowait,
 			&force, &ask,
@@ -334,6 +337,13 @@ main(ac, av)
 		usage(0);
 	else if (xhelp)
 		xusage(0);
+	if (prvers) {
+		printf("sformat %s (%s-%s-%s)\n\n", fmt_version, HOST_CPU, HOST_VENDOR, HOST_OS);
+		printf("Copyright (C) 1986-1991, 93-97, 2000-2001 Jrg Schilling\n");
+		printf("This is free software; see the source for copying conditions.  There is NO\n");
+		printf("warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
+		exit(0);
+	}
 
 	if (Sstart && Sstop)
 		comerrno(EX_BAD, "Only one of start/stop\n");
@@ -371,7 +381,7 @@ main(ac, av)
 	if (MAXbad != -1 && (MAXbad <= 0L || MAXbad > 127L))
 		comerrno(EX_BAD, "Bad number of max. bad Blocks / verify loop\n");
 	if (Vstart < 0L || (Vend > 0L && Vstart > Vend))
-		comerrno(EX_BAD, "Bad verify start %d.\n", Vstart);
+		comerrno(EX_BAD, "Bad verify start %ld.\n", Vstart);
 
 	if (cur_disk.nhead == 0 || cur_disk.nhead > 32) /* XXX */
 		comerrno(EX_BAD, "Bad number of heads\n");
@@ -428,11 +438,35 @@ main(ac, av)
 	}
 	getstarttime();
 
-	if (!scsi_open(NULL, scsibus, target, lun))
-		comerr("Cannot open /dev/scg?\n");
+	scg_remote();
+	if (dev) {
+		char	errstr[80];
 
-	Sbufsize = scsi_bufsize(256*1024L);
-	if ((Sbuf = scsi_getbuf(Sbufsize)) == NULL)
+/*		if ((scgp = scg_open(dev, errstr, sizeof(errstr), debug, lverbose)) == (SCSI *)0)*/
+		if ((scgp = scg_open(dev, errstr, sizeof(errstr), debug, 0)) == (SCSI *)0)
+			comerr("%s%sCannot open SCSI driver.\n", errstr, errstr[0]?". ":"");
+	} else {
+		if (scsibus == -1 && target >= 0 && lun >= 0)
+			scsibus = 0;
+
+		scgp = scg_smalloc();
+		scgp->debug = debug;
+		scgp->kdebug = kdebug;
+
+		scg_settarget(scgp, scsibus, target, lun);
+		if (scg__open(scgp, NULL) <= 0)
+			comerr("Cannot open SCSI driver.\n");
+	}
+	scgp->silent = silent;
+	scgp->verbose = verbose;
+	scgp->debug = debug;
+	scgp->kdebug = kdebug;
+	if (deftimeout > 0)
+		scgp->deftimeout = deftimeout;
+	scgp->noparity = noparity;
+
+	Sbufsize = scg_bufsize(scgp, 256*1024L);
+	if ((Sbuf = scg_getbuf(scgp, Sbufsize)) == NULL)
 		comerr("Cannot get SCSI I/O buffer.\n");
 	if (debug)
 		printf("bufsize: %ld bufaddr: %p\n", Sbufsize, Sbuf);
@@ -462,20 +496,22 @@ main(ac, av)
 	}
 	if (thistime && thistime < starttime.tv_sec)
 		alarm(2);
-	if (scsibus < 0)
-		scsibus = 0;
-	if (target < 0 || target > 7 || lun < 0 || lun > 7) {
-		if (autoformat || target != -1 || lun != -1)
+
+/* XXX schon vor scg__open()! */
+/*	if (scgp->scsibus < 0)*/
+/*		scgp->scsibus = 0;*/
+	if (scg_target(scgp) < 0 || scg_target(scgp) > 7 || scg_lun(scgp) < 0 || scg_lun(scgp) > 7) {
+		if (autoformat || scg_target(scgp) != -1 || scg_lun(scgp) != -1)
 			errmsgno(EX_BAD, "Target or lun missing or bad\n");
 		if (autoformat)
 			exit(EX_BAD);
-		select_target();
+		select_target(scgp);
 		exit(0);
 	}
 	if (prgeom || prcurgeom)
-		ret = printgeom(prcurgeom);
+		ret = printgeom(scgp, prcurgeom);
 	else
-		ret = format_one();
+		ret = format_one(scgp);
 	exit(ret);
 	/* NOTREACHED */
 	return (ret);		/* Keep lint happy */
@@ -491,39 +527,68 @@ print_product(ip)
 	if (ip->add_len < 31) {
 		printf("NON CCS ");
 	}
-	scsiprintdev(ip);
+	scg_printdev(ip);
 }
 
 LOCAL void
-select_target()
+select_target(scgp)
+	SCSI	*scgp;
 {
 	int	initiator;
-	int	cscsibus = scsibus;
-	int	ctarget = target;
-	int	clun	= lun;
+#ifdef	FMT
+	int	cscsibus = scg_scsibus(scgp);
+	int	ctarget  = scg_target(scgp);
+	int	clun	 = scg_lun(scgp);
+#endif
 	int	n;
 	int	low	= -1;
 	int	high	= -1;
+	int	bus;
+	int	tgt;
+	int	lun = 0;
+	BOOL	have_tgt;
 
-	silent++;
+	scgp->silent++;
 
-	for (scsibus=0; scsibus < 8; scsibus++) {
-		initiator = scg_initiator_id(scsibus);
-		if (!scsi_havebus(scsibus))
+	for (bus=0; bus < 16; bus++) {
+		scg_settarget(scgp, bus, 0, 0);
+
+		if (!scg_havebus(scgp, bus))
 			continue;
-		printf("scsibus%d:\n", scsibus);
 
-		for (target=0, lun=0; target < 8; target++) {
-			n = scsibus*10 + target;
-		
-			if (print_disknames(scsibus, target, -1) < 8)
+		initiator = scg_initiator_id(scgp);
+		printf("scsibus%d:\n", bus);
+
+		for (tgt=0; tgt < 16; tgt++) {
+			n = bus*100 + tgt;
+
+			scg_settarget(scgp, bus, tgt, lun);
+			have_tgt = unit_ready(scgp) || scgp->scmd->error != SCG_FATAL;
+
+			if (!have_tgt && tgt > 7) {
+				if (scgp->scmd->ux_errno == EINVAL)
+					break;
+				continue;
+			}
+
+#ifdef	FMT
+			if (print_disknames(bus, tgt, -1) < 8)
 				printf("\t");
-			printf("\t%2d) ", n);
-			if (target == initiator) {
+			else
+				printf(" ");
+#else
+			printf("\t");
+#endif
+			if (printf("%d,%d,%d", bus, tgt, lun) < 8)
+				printf("\t");
+			else
+				printf(" ");
+			printf("%3d) ", n);
+			if (tgt == initiator) {
 				printf("HOST ADAPTOR\n");
 				continue;
 			}
-			if (!unit_ready() && scmd.error == SCG_FATAL) {
+			if (!have_tgt) {
 				printf("*\n");
 				continue;
 			}
@@ -531,54 +596,70 @@ select_target()
 				low = n;
 			high = n;
 
-			getdev(FALSE);
-			print_product(&inq);
+			getdev(scgp, FALSE);
+			print_product(scgp->inq);
 		}
 	}
-	silent--;
+	scgp->silent--;
 
 	if (low < 0)
 		comerrno(EX_BAD, "No target found.\n");
 	n = -1;
+#ifdef	FMT
 	getint("Select target", &n, low, high); 
-	scsibus = n/10;
-	target = n%10;
-	select_unit();
+	bus = n/100;
+	tgt = n%100;
+	scg_settarget(scgp, bus, tgt, lun);
+	select_unit(scgp);
 
-	scsibus	= cscsibus;
-	target	= ctarget;
-	lun	= clun;
+	scg_settarget(scgp, cscsibus, ctarget, clun);
+#else
+	exit(0);
+#endif
 }
 
 LOCAL void
-select_unit()
+select_unit(scgp)
+	SCSI	*scgp;
 {
 	int	initiator;
-	int	clun	= lun;
+	int	clun	= scg_lun(scgp);
 	int	low	= -1;
 	int	high	= -1;
+	int	lun;
 
-	silent++;
+	scgp->silent++;
 
-	printf("scsibus%d target %d:\n", scsibus, target);
+	printf("scsibus%d target %d:\n", scg_scsibus(scgp), scg_target(scgp));
 
-	initiator = scg_initiator_id(scsibus);
+	initiator = scg_initiator_id(scgp);
 	for (lun=0; lun < 8; lun++) {
 
-		if (print_disknames(scsibus, target, lun) < 8)
+#ifdef	FMT
+		if (print_disknames(scg_scsibus(scgp), scg_target(scgp), lun) < 8)
 			printf("\t");
-		printf("\t%2d) ", lun);
-		if (target == initiator) {
+		else
+			printf(" ");
+#else
+		printf("\t");
+#endif		
+		if (printf("%d,%d,%d", scg_scsibus(scgp), scg_target(scgp), lun) < 8)
+			printf("\t");
+		else
+			printf(" ");
+		printf("%3d) ", lun);
+		if (scg_target(scgp) == initiator) {
 			printf("HOST ADAPTOR\n");
 			continue;
 		}
-		if (!unit_ready() && scmd.error == SCG_FATAL) {
+		scg_settarget(scgp, scg_scsibus(scgp), scg_target(scgp), lun);
+		if (!unit_ready(scgp) && scgp->scmd->error == SCG_FATAL) {
 			printf("*\n");
 			continue;
 		}
-		if (unit_ready()) {
+		if (unit_ready(scgp)) {
 			/* non extended sense illegal lun */
-			if (scmd.sense.code == 0x25) {
+			if (scgp->scmd->sense.code == 0x25) {
 				printf("BAD UNIT\n");
 				continue;
 			}
@@ -587,47 +668,53 @@ select_unit()
 			low = lun;
 		high = lun;
 
-		getdev(FALSE);
-		print_product(&inq);
+		getdev(scgp, FALSE);
+		print_product(scgp->inq);
 	}
-	silent--;
+	scgp->silent--;
 
 	if (low < 0)
 		comerrno(EX_BAD, "No lun found.\n");
 	lun = -1;
+#ifdef	FMT
 	getint("Select lun", &lun, low, high); 
-	format_one();
+	scg_settarget(scgp, scg_scsibus(scgp), scg_target(scgp), lun);
+	format_one(scgp);
+#else
+	exit(0);
+#endif
 	
-	lun	= clun;
+	scg_settarget(scgp, scg_scsibus(scgp), scg_target(scgp), clun);
 }
 
 LOCAL int
-format_one()
+format_one(scgp)
+	SCSI	*scgp;
 {
 	struct disk	*dp = &cur_disk;
 	int	ret	= 0;
 	int	i;
 
-	printf("scsibus%d target %d lun %d\n", scsibus, target, lun);
-	if (checkmount(scsibus, target, lun, -1L, 0L)) {
+	printf("scsibus%d target %d lun %d\n", scg_scsibus(scgp), scg_target(scgp), scg_lun(scgp));
+	if (checkmount(scg_scsibus(scgp), scg_target(scgp), scg_lun(scgp), -1L, 0L)) {
 		printf("WARNING: Disk has mounted partitions. ");
 		if (!yes("Continue? "))
 			exit(EX_BAD);
 	}
 	if (do_inq)
-		silent++;
-	getdev(TRUE);
-	if (scmd.error == SCG_FATAL)
+		scgp->silent++;
+	getdev(scgp, TRUE);
+	if (scgp->scmd->error == SCG_FATAL)
 		comerrno(EX_BAD, "Cannot select Drive.\n");
 	if (!do_inq)
-		printdev();
+		printdev(scgp);
 	else
-		silent--;
+		scgp->silent--;
 	if (do_inq) {
-		if (verbose && (inq.add_len+5) > sizeof(inq)) {
-			inquiry(Sbuf, (int)(inq.add_len+5));
+		if (scgp->verbose && (scgp->inq->add_len+5) > sizeof(struct scsi_inquiry)) {
+			inquiry(scgp, Sbuf, (int)(scgp->inq->add_len+5));
 
-			for (i = 0; i < (int)inq.add_len+5; i++) {
+			for (i = 0; i < (int)scgp->inq->add_len+5; i++) {
 				if ((Sbuf[i]&0xFF) >= ' ' &&
 							(Sbuf[i]&0xFF) <= '~')
 					printf("%c", Sbuf[i]);
@@ -639,24 +726,24 @@ format_one()
 		return (0);
 	}
 	if (Sstart) {
-		start_stop_unit(Sstart);
+		start_stop_unit(scgp, Sstart);
 		return (0);
 	}
-	silent++;
+	scgp->silent++;
 	for (i=0; ; i++) {
-		if (unit_ready())
+		if (unit_ready(scgp))
 			break;
-		if (i > 30 || scmd.error >= SCG_FATAL) {
-			scsiprinterr("test unit ready");
+		if (i > 30 || scgp->scmd->error >= SCG_FATAL) {
+			scg_printerr(scgp);
 			comerrno(EX_BAD, "Drive not ready.\n");
 		}
-		if (scmd.scb.busy ||
-			(scmd.scb.chk &&
-			(scmd.sense_count >= 3 && scmd.sense.code >= 0x70 &&
-				((struct scsi_ext_sense *)&scmd.sense)->key
+		if (scgp->scmd->scb.busy ||
+			(scgp->scmd->scb.chk &&
+			(scgp->scmd->sense_count >= 3 && scgp->scmd->sense.code >= 0x70 &&
+				((struct scsi_ext_sense *)&scgp->scmd->sense)->key
 				== SC_NOT_READY)) ||
-				scmd.sense.code == 0x04 ||
-				scmd.u_sense.cmd_sense[0] == 0x84)
+				scgp->scmd->sense.code == 0x04 ||
+				scgp->scmd->u_sense.cmd_sense[0] == 0x84)
 			sleep(1);
 	}
 	/*
@@ -664,81 +751,81 @@ format_one()
 	 * wenn das Laufwerk nicht bereit ist, wird hier noch einmal
 	 * versucht, den Controllertyp zu bestimmen.
 	 */ 
-	if (dev == DEV_ACB40X0)
-		getdev(FALSE);
-	silent--;
+	if (scgp->dev == DEV_ACB40X0)
+		getdev(scgp, FALSE);
+	scgp->silent--;
 
 
-	silent++;
-	if (read_capacity() >= 0)	/* Adaptec 40x0 reagiert uebel, wenn*/
-		(void)seek_scsi(0L);	/* die Platte nicht formatiert ist */
+	scgp->silent++;
+	if (read_capacity(scgp) >= 0)		/* Adaptec 40x0 reagiert uebel, wenn*/
+		(void)seek_scsi(scgp, 0L);	/* die Platte nicht formatiert ist */
 	for (i=0; i < 100; i++) {
 		usleep(200000);
-		if (unit_ready())
+		if (unit_ready(scgp))
 			break;
 	}
-	silent--;
-	(void)rezero_unit();
+	scgp->silent--;
+	(void)rezero_unit(scgp);
 
 	/*
 	 * Exit here on wrong device type?
 	 */
-	if (inq.type == INQ_DASD || inq.type == INQ_ROMD ||
-						inq.type == INQ_OMEM) {
-		read_sinfo(dp, FALSE);
-		print_sinfo(stdout);
+	if (scgp->inq->type == INQ_DASD || scgp->inq->type == INQ_ROMD ||
+						scgp->inq->type == INQ_OMEM) {
+		read_sinfo(scgp, dp, FALSE);
+		print_sinfo(stdout, scgp);
 	}
 
 	if (reassign || greassign) {
-		reassign_one();
+		reassign_one(scgp);
 		/* NOTREACHED */
 	} else if (translate_blk) {
-		if (strindex("EMULEX", inq.info))
-			read_sector_header();
+		if (strindex("EMULEX", scgp->inq->info))
+			read_sector_header(scgp);
 		else
-			translate_lba();
+			translate_lba(scgp);
 		return(0);
 	} else if (veri || repair) {
 		int	nbad = 0;
 		
-		verify_disk(dp, 0, Vstart, Vend, MAXbad);
+		verify_disk(scgp, dp, 0, Vstart, Vend, MAXbad);
 		nbad = print_bad();
-		if (!ccs(dev)) {		/* XXX Adaptec ?? */
+		if (!is_ccs(scgp->dev)) {		/* XXX Adaptec ?? */
 			/* Only print them */
-			(void)bad_to_def();
+			(void)bad_to_def(scgp);
 		} else if (repair && nbad > 0) {
 		        printf("WARNING: Repair may change data on disk.\n");
 		        if(yes("Do you want to continue? "))
-				repair_found_blocks(nbad);
+				repair_found_blocks(scgp, nbad);
 		}
 		return (0);
 	} else if (modesel) {
-		do_modes();
+		do_modes(scgp);
 		/* NOTREACHED */
 	} else if (randrw) {
 		printf("WARNING: Random read/write-test may destroy data.\n");
 	        if(yes("Do you want to continue? "))
-		        return(random_rw_test(Vstart, Vend));
+		        return(random_rw_test(scgp, Vstart, Vend));
 		return(0);
 	}
 	else if (ESDI)
-		esdi_command();
+		esdi_command(scgp);
 	else if (clearnull)
-		clear_phys_null();
+		clear_phys_null(scgp);
 	else if (readnull)
-		read_phys_null(dev!=DEV_MD21 && dev!=DEV_MD23);
+		read_phys_null(scgp, scgp->dev!=DEV_MD21 && scgp->dev!=DEV_MD23);
 	else if (damage)
-		damage_phys_blk();
+		damage_phys_blk(scgp);
 	else if (prdefect) {
-		(void)read_defect_list(1, SC_DEF_BLOCK, TRUE);flush();
-		(void)read_defect_list(1, SC_DEF_BFI, TRUE);flush();
-		(void)read_defect_list(1, SC_DEF_PHYS, TRUE);flush();
-		(void)read_defect_list(2, SC_DEF_BLOCK, TRUE);flush();
-		(void)read_defect_list(2, SC_DEF_BFI, TRUE);flush();
-		(void)read_defect_list(2, SC_DEF_PHYS, TRUE);flush();
+		(void)read_defect_list(scgp, 1, SC_DEF_BLOCK, TRUE);flush();
+		(void)read_defect_list(scgp, 1, SC_DEF_BFI, TRUE);flush();
+		(void)read_defect_list(scgp, 1, SC_DEF_PHYS, TRUE);flush();
+		(void)read_defect_list(scgp, 2, SC_DEF_BLOCK, TRUE);flush();
+		(void)read_defect_list(scgp, 2, SC_DEF_BFI, TRUE);flush();
+		(void)read_defect_list(scgp, 2, SC_DEF_PHYS, TRUE);flush();
 		return(0);
 	} else if (Sstart || Sstop) {
-		start_stop_unit(Sstart);
+		start_stop_unit(scgp, Sstart);
 		return (0);
 	} else if (seek) {
 		int	err = 0;
@@ -746,23 +833,23 @@ format_one()
 		long	end;
 		long	amount;
 
-		end = cap.c_baddr;
+		end = scgp->cap->c_baddr;
 		if (start < 0 || start > end)
 			start = 0L;
 		if (Vend > 0 && Vend < end)
 			end = Vend;
 		amount = end - start + 1;
 		printf("start: %ld end: %ld amount: %ld last baddr: %ld\n",
-					start, end, amount, cap.c_baddr);
+					start, end, amount, (long)scgp->cap->c_baddr);
 
 		printf("Select full stroke or random seeks:\n");
 		if (yes("Full stroke seek? ")) for(;;) {
 			if (i == 0)
 				getstarttime();
 			i++;
-			if (read_scsi(Sbuf, start, 1) < 0)
+			if (read_scsi(scgp, Sbuf, start, 1) < 0)
 				err++;
-			if (read_scsi(Sbuf, end, 1) < 0)
+			if (read_scsi(scgp, Sbuf, end, 1) < 0)
 				err++;
 
 			if (i% 1000 == 0) {
@@ -776,7 +863,7 @@ format_one()
 			if (i == 0)
 				getstarttime();
 			i++;
-			if (read_scsi(Sbuf, start + rand()%amount, 1) < 0) {
+			if (read_scsi(scgp, Sbuf, start + rand()%amount, 1) < 0) {
 				err++;
 				printf("Gesamt: %d errs: %d\n", i, err);
 			}
@@ -790,38 +877,38 @@ format_one()
 		}
 	}
 
-	silent++;
-	if (read_capacity() >= 0)	/* Adaptec 40x0 reagiert uebel, wenn*/
-		(void)seek_scsi(0L);	/* die Platte nicht formatiert ist */
+	scgp->silent++;
+	if (read_capacity(scgp) >= 0)		/* Adaptec 40x0 reagiert uebel, wenn*/
+		(void)seek_scsi(scgp, 0L);	/* die Platte nicht formatiert ist */
 	for (i=0; i < 100; i++) {
 		usleep(100000);
-		if (unit_ready())
+		if (unit_ready(scgp))
 			break;
 	}
-	silent--;
-	(void)rezero_unit();
-	if (inq.type != INQ_DASD && inq.type != INQ_ROMD
-						&& inq.type != INQ_OMEM) {
-		comerrno(EX_BAD, "Bad Device type: 0x%x\n", inq.type);
-	} else switch (dev) {
+	scgp->silent--;
+	(void)rezero_unit(scgp);
+	if (scgp->inq->type != INQ_DASD && scgp->inq->type != INQ_ROMD
+						&& scgp->inq->type != INQ_OMEM) {
+		comerrno(EX_BAD, "Bad Device type: 0x%x\n", scgp->inq->type);
+	} else switch (scgp->dev) {
 
 	case DEV_ACB40X0:
 	case DEV_ACB4000:
 	case DEV_ACB4010:
 	case DEV_ACB4070:
-	case DEV_ACB5500:	i = Adaptec4000();	break;
+	case DEV_ACB5500:	i = Adaptec4000(scgp);	break;
 	case DEV_ACB4520A:
 	case DEV_ACB4525:
 	case DEV_MD21:
 	case DEV_MD23:
 	case DEV_NON_CCS_DSK:
 	case DEV_CCS_GENDISK:
-				i = Emulex_MD21();	break;
+				i = Emulex_MD21(scgp);	break;
 	case DEV_SONY_SMO:
-				i = Emulex_MD21();	break;/* Temporaer */
+				i = Emulex_MD21(scgp);	break;/* Temporaer */
 	default:
 	case DEV_UNKNOWN:	errmsgno(EX_BAD, "Unknown Device\n");
-				i = Emulex_MD21();	break;
+				i = Emulex_MD21(scgp);	break;
 	}
 
 	prstats();
@@ -837,42 +924,44 @@ format_one()
 		}
 	}
 
-	create_label(dp);
+	create_label(scgp, dp);
 
-	ret = verify_and_repair_disk(dp);
+	ret = verify_and_repair_disk(scgp, dp);
 
-	label_disk(dp);
-	convert_def_blk();
-	write_def_blk(TRUE);
+	label_disk(scgp, dp);
+	convert_def_blk(scgp);
+	write_def_blk(scgp, TRUE);
 	return (ret);
 }
 
 EXPORT void
-getdev(print)
+getdev(scgp, print)
+	SCSI	*scgp;
 	BOOL	print;
 {
 	BOOL	got_inquiry = TRUE;
+	register struct scsi_inquiry *inq = scgp->inq;
 
-	fillbytes((caddr_t)&inq, sizeof(inq), '\0');
-	dev = DEV_UNKNOWN;
-	silent++;
-	(void)unit_ready();
-	if (scmd.error >= SCG_FATAL &&
-				!(scmd.scb.chk && scmd.sense_count > 0)) {
-		silent--;
+	fillbytes((caddr_t)inq, sizeof(*inq), '\0');
+	scgp->dev = DEV_UNKNOWN;
+	scgp->silent++;
+	(void)unit_ready(scgp);
+	if (scgp->scmd->error >= SCG_FATAL &&
+				!(scgp->scmd->scb.chk && scgp->scmd->sense_count > 0)) {
+		scgp->silent--;
 		return;
 	}
 
 
-/*	if (scmd.error < SCG_FATAL || scmd.scb.chk && scmd.sense_count > 0){*/
+/*	if (scgp->scmd->error < SCG_FATAL || scgp->scmd->scb.chk && scgp->scmd->sense_count > 0){*/
 
-	if (inquiry((caddr_t)&inq, sizeof(inq)) < 0) {
+	if (inquiry(scgp, (caddr_t)inq, sizeof(*inq)) < 0) {
 		got_inquiry = FALSE;
-		if (verbose) {
+		if (scgp->verbose) {
 			printf(
 		"error: %d scb.chk: %d sense_count: %d sense.code: 0x%x\n",
-				scmd.error, scmd.scb.chk,
-				scmd.sense_count, scmd.sense.code);
+				scgp->scmd->error, scgp->scmd->scb.chk,
+				scgp->scmd->sense_count, scgp->scmd->sense.code);
 		}
 			/*
 			 * Folgende Kontroller kennen das Kommando
@@ -886,139 +975,140 @@ getdev(print)
 			 * sie sind dann nicht zu unterscheiden.
 			 */
 
-		if (scmd.scb.chk && scmd.sense_count == 4) {
+		if (scgp->scmd->scb.chk && scgp->scmd->sense_count == 4) {
 			/* Test auf SYSGEN			 */
-			(void)qic02(0x12);	/* soft lock on  */
-			if (qic02(1) < 0) {	/* soft lock off */
-				dev = DEV_ACB40X0;
-				dev = acbdev();
+			(void)qic02(scgp, 0x12);	/* soft lock on  */
+			if (qic02(scgp, 1) < 0) {	/* soft lock off */
+				scgp->dev = DEV_ACB40X0;
+				scgp->dev = acbdev(scgp);
 			} else {
-				dev = DEV_SC4000;
-				inq.type = INQ_SEQD;
-				inq.removable = 1;
+				scgp->dev = DEV_SC4000;
+				inq->type = INQ_SEQD;
+				inq->removable = 1;
 			}
 		}
 	}
-	switch (inq.type) {
+	switch (inq->type) {
 
 	case INQ_DASD:
-		if (inq.add_len == 0) {
-			if (dev == DEV_UNKNOWN && got_inquiry) {
-				dev = DEV_ACB5500;
-				strcpy(inq.vendor_info,
+		if (inq->add_len == 0) {
+			if (scgp->dev == DEV_UNKNOWN && got_inquiry) {
+				scgp->dev = DEV_ACB5500;
+				strcpy(inq->vendor_info,
 					"ADAPTEC ACB-5500        FAKE");
 
-			} else switch (dev) {
+			} else switch (scgp->dev) {
 
 			case DEV_ACB40X0:
-				strcpy(inq.vendor_info,
+				strcpy(inq->vendor_info,
 					"ADAPTEC ACB-40X0        FAKE");
 				break;
 			case DEV_ACB4000:
-				strcpy(inq.vendor_info,
+				strcpy(inq->vendor_info,
 					"ADAPTEC ACB-4000        FAKE");
 				break;
 			case DEV_ACB4010:
-				strcpy(inq.vendor_info,
+				strcpy(inq->vendor_info,
 					"ADAPTEC ACB-4010        FAKE");
 				break;
 			case DEV_ACB4070:
-				strcpy(inq.vendor_info,
+				strcpy(inq->vendor_info,
 					"ADAPTEC ACB-4070        FAKE");
 				break;
 			}
-		} else if (inq.add_len < 31) {
-			dev = DEV_NON_CCS_DSK;
+		} else if (inq->add_len < 31) {
+			scgp->dev = DEV_NON_CCS_DSK;
 
-		} else if (strindex("EMULEX", inq.info)) {
-			if (strindex("MD21", inq.ident))
-				dev = DEV_MD21;
-			if (strindex("MD23", inq.ident))
-				dev = DEV_MD23;
+		} else if (strindex("EMULEX", inq->info)) {
+			if (strindex("MD21", inq->ident))
+				scgp->dev = DEV_MD21;
+			if (strindex("MD23", inq->ident))
+				scgp->dev = DEV_MD23;
 			else
-				dev = DEV_CCS_GENDISK;
-		} else if (strindex("ADAPTEC", inq.info)) {
-			if (strindex("ACB-4520", inq.ident))
-				dev = DEV_ACB4520A;
-			if (strindex("ACB-4525", inq.ident))
-				dev = DEV_ACB4525;
+				scgp->dev = DEV_CCS_GENDISK;
+		} else if (strindex("ADAPTEC", inq->info)) {
+			if (strindex("ACB-4520", inq->ident))
+				scgp->dev = DEV_ACB4520A;
+			if (strindex("ACB-4525", inq->ident))
+				scgp->dev = DEV_ACB4525;
 			else
-				dev = DEV_CCS_GENDISK;
-		} else if (strindex("SONY", inq.info) &&
-					strindex("SMO-C501", inq.ident)) {
-			dev = DEV_SONY_SMO;
+				scgp->dev = DEV_CCS_GENDISK;
+		} else if (strindex("SONY", inq->info) &&
+					strindex("SMO-C501", inq->ident)) {
+			scgp->dev = DEV_SONY_SMO;
 		} else {
-			dev = DEV_CCS_GENDISK;
+			scgp->dev = DEV_CCS_GENDISK;
 		}
 		break;
 
 	case INQ_SEQD:
-		if (dev == DEV_SC4000) {
-			strcpy(inq.vendor_info,
+		if (scgp->dev == DEV_SC4000) {
+			strcpy(inq->vendor_info,
 				"SYSGEN  SC4000          FAKE");
-		} else if (inq.add_len == 0 &&
-					inq.removable &&
-						inq.ansi_version == 1) {
-			dev = DEV_MT02;
-			strcpy(inq.vendor_info,
+		} else if (inq->add_len == 0 &&
+					inq->removable &&
+						inq->ansi_version == 1) {
+			scgp->dev = DEV_MT02;
+			strcpy(inq->vendor_info,
 				"EMULEX  MT02            FAKE");
 		}
 		break;
 
 	case INQ_OPTD:
-		if (strindex("RXT-800S", inq.ident))
-			dev = DEV_RXT800S;
+		if (strindex("RXT-800S", inq->ident))
+			scgp->dev = DEV_RXT800S;
 		break;
 
 	case INQ_PROCD:
-		if (strindex("BERTHOLD", inq.info)) {
-			if (strindex("", inq.ident))
-				dev = DEV_HRSCAN;
+		if (strindex("BERTHOLD", inq->info)) {
+			if (strindex("", inq->ident))
+				scgp->dev = DEV_HRSCAN;
 		}
 		break;
 
 	case INQ_SCAN:
-		dev = DEV_MS300A;
+		scgp->dev = DEV_MS300A;
 		break;
 	}
-	silent--;
+	scgp->silent--;
 	if (!print)
 		return;
 
-	if (dev == DEV_UNKNOWN && !got_inquiry)
+	if (scgp->dev == DEV_UNKNOWN && !got_inquiry)
 		return;
 
 	printf("Device type    : ");
-	scsiprintdev(&inq);
-	printf("Version        : %d\n", inq.ansi_version);
-	printf("Response Format: %d\n", inq.data_format);
-	if (inq.data_format >= 2) {
+	scg_printdev(inq);
+	printf("Version        : %d\n", inq->ansi_version);
+	printf("Response Format: %d\n", inq->data_format);
+	if (inq->data_format >= 2) {
 		printf("Capabilities   : ");
-		if (inq.aenc)		printf("AENC ");
-		if (inq.termiop)	printf("TERMIOP ");
-		if (inq.reladr)		printf("RELADR ");
-		if (inq.wbus32)		printf("WBUS32 ");
-		if (inq.wbus16)		printf("WBUS16 ");
-		if (inq.sync)		printf("SYNC ");
-		if (inq.linked)		printf("LINKED ");
-		if (inq.cmdque)		printf("CMDQUE ");
-		if (inq.softreset)	printf("SOFTRESET ");
+		if (inq->aenc)		printf("AENC ");
+		if (inq->termiop)	printf("TERMIOP ");
+		if (inq->reladr)	printf("RELADR ");
+		if (inq->wbus32)	printf("WBUS32 ");
+		if (inq->wbus16)	printf("WBUS16 ");
+		if (inq->sync)		printf("SYNC ");
+		if (inq->linked)	printf("LINKED ");
+		if (inq->cmdque)	printf("CMDQUE ");
+		if (inq->softreset)	printf("SOFTRESET ");
 		printf("\n");
 	}
-	if (inq.add_len >= 31 ||
-			inq.info[0] || inq.ident[0] || inq.revision[0]) {
-		printf("Vendor_info    : '%.8s'\n", inq.info);
-		printf("Identifikation : '%.16s'\n", inq.ident);
-		printf("Revision       : '%.4s'\n", inq.revision);
+	if (inq->add_len >= 31 ||
+			inq->info[0] || inq->ident[0] || inq->revision[0]) {
+		printf("Vendor_info    : '%.8s'\n", inq->info);
+		printf("Identifikation : '%.16s'\n", inq->ident);
+		printf("Revision       : '%.4s'\n", inq->revision);
 	}
 }
 
 LOCAL void
-printdev()
+printdev(scgp)
+	SCSI	*scgp;
 {
 	printf("Device seems to be: ");
 
-	switch (dev) {
+	switch (scgp->dev) {
 
 	case DEV_UNKNOWN:	printf("unknown");		break;
 	case DEV_ACB40X0:	printf("Adaptec 4000/4010/4070");break;
@@ -1045,7 +1135,8 @@ printdev()
 }
 
 LOCAL void
-translate_lba()
+translate_lba(scgp)
+	SCSI	*scgp;
 {
 	struct scsi_def_list def;
 	long	baddr = 0L;
@@ -1056,16 +1147,17 @@ loop:
 
 	fillbytes((caddr_t)&def, sizeof(def), '\0');
 	i = sizeof(struct scsi_def_bfi);	/* Ein Defekt */
-	i_to_short(def.hd.length, i);
+	i_to_2_byte(def.hd.length, i);
 
-	if (translate(&def.def_bfi[0], baddr) >= 0) {
+	if (translate(scgp, &def.def_bfi[0], baddr) >= 0) {
 		print_def_bfi(&def);
 	}
 	goto loop;
 }
 
 LOCAL void
-read_sector_header()
+read_sector_header(scgp)
+	SCSI	*scgp;
 {
 	struct	scsi_send_diag_cmd	cmd;
 	register struct	scsi_sector_header	*header;
@@ -1079,17 +1171,17 @@ loop:
 	fillbytes((caddr_t)bh, sizeof(bh), '\0');
 	cmd.cmd = 7;	/* Read Header */
 	getlong("Block Address", &baddr, 0L, 1000000L);
-	i_to_long(cmd.addr, baddr);
+	i_to_4_byte(cmd.addr, baddr);
 	cmd.addr[0] |= (yes("Physical Address? ")<<7);
 /*	print_bk(baddr);*/
 
-	if (send_diagnostic((caddr_t)&cmd, sizeof(cmd)) >= 0)
-		if (receive_diagnostic((caddr_t)bh, sizeof(bh))>=0) {
-			maxi = (sizeof(bh) - scmd.resid)/5;
+	if (send_diagnostic(scgp, (caddr_t)&cmd, sizeof(cmd)) >= 0)
+		if (receive_diagnostic(scgp, (caddr_t)bh, sizeof(bh))>=0) {
+			maxi = (sizeof(bh) - scg_getresid(scgp))/5;
 			for (i=0; i < maxi; i++) {
 			header = (struct scsi_sector_header *)&bh[i*5];
 			printf("Cyl %4d  Head %2d  Sec %2d (%2d)%s %s %s\n",
-				a_to_u_short(header->cyl),
+				a_to_u_2_byte(header->cyl),
 				header->head,
 				header->sec, i,
 				header->dt ? "Defective Track" : "",
@@ -1101,7 +1193,8 @@ loop:
 }
 
 LOCAL void
-esdi_command()
+esdi_command(scgp)
+	SCSI	*scgp;
 {
 	struct	scsi_send_diag_cmd	cmd;
 	char	bh[512];
@@ -1112,11 +1205,11 @@ esdi_command()
 	fillbytes((caddr_t)bh, sizeof(bh), '\0');
 	cmd.cmd = 4;	/* Pass Drive Command */
 	cmd.addr[0] = 0xFF;
-	i_to_short(&cmd.addr[1], ESDI);
+	i_to_2_byte(&cmd.addr[1], ESDI);
 
-	if (send_diagnostic((caddr_t)&cmd, sizeof(cmd)) >= 0)
-		if (receive_diagnostic((caddr_t)bh, sizeof(bh))>=0) {
-			maxi = (sizeof(bh) - scmd.resid);
+	if (send_diagnostic(scgp, (caddr_t)&cmd, sizeof(cmd)) >= 0)
+		if (receive_diagnostic(scgp, (caddr_t)bh, sizeof(bh))>=0) {
+			maxi = (sizeof(bh) - scg_getresid(scgp));
 			i = 0;
 			if (maxi)
 				printf("ESDI Status: 0x%02X\n", bh[i++]&0xFF);
@@ -1257,7 +1350,7 @@ prstats()
 	getstoptime();
 	sec = gettimediff(&tv);
 
-	printf("Time total: %ld.%03ldsec\n", tv.tv_sec, tv.tv_usec/1000);
+	printf("Time total: %ld.%03ldsec\n", (long)tv.tv_sec, (long)tv.tv_usec/1000);
 	return (sec);
 }
 
