@@ -1,7 +1,7 @@
-/* @(#)makelabel.c	1.39 98/08/16 Copyright 1988 J. Schilling */
+/* @(#)makelabel.c	1.45 00/05/07 Copyright 1988 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)makelabel.c	1.39 98/08/16 Copyright 1988 J. Schilling";
+	"@(#)makelabel.c	1.45 00/05/07 Copyright 1988 J. Schilling";
 #endif
 /*
  *	Routines to create / modify a label
@@ -32,7 +32,7 @@ static	char sccsid[] =
 #ifdef	SVR4
 #include <termios.h>
 #endif
-#include <fcntl.h>
+#include <fctldefs.h>
 #include <sys/file.h>
 #include <dsklabel.h>
 #ifndef	HAVE_DKIO
@@ -43,50 +43,54 @@ static	char sccsid[] =
 #endif
 #include <unixstd.h>
 #include <stdxlib.h>
-#include <string.h>
-#include "fmt.h"
-#include "scsireg.h"
+#include <strdefs.h>
+#include <schily.h>
 
-char	labelbuf[80];
-struct	dk_label *d_label;
+#include <scg/scsireg.h>
+#include <scg/scsitransp.h>
+
+#include "fmt.h"
+
+LOCAL	char	labelbuf[80];
+extern	struct	dk_label *d_label;
 
 char	labelname[] = "Label";
 char	labelproto[] = "Label.prototype";
 char	*Lname = labelname;
 char	*Lproto = labelproto;
 
-EXPORT	void	set_default_vtmap __PR((struct dk_label *lp));
-EXPORT	unsigned short do_cksum	__PR((struct dk_label *l));
-EXPORT	BOOL	check_vtmap	__PR((struct dk_label *lp, BOOL set));
-EXPORT	void	setlabel_from_val __PR((struct disk *dp, struct dk_label *lp));
-EXPORT	void	makelabel	__PR((struct disk *dp, struct dk_label *lp));
-LOCAL	void	chpart		__PR((struct disk *dp, struct dk_label *lp, int idx));
+EXPORT	void	set_default_vtmap	__PR((struct dk_label *lp));
+EXPORT	unsigned short do_cksum		__PR((struct dk_label *l));
+EXPORT	BOOL	check_vtmap		__PR((struct dk_label *lp, BOOL set));
+EXPORT	void	setlabel_from_val	__PR((SCSI *scgp, struct disk *dp, struct dk_label *lp));
+EXPORT	void	makelabel		__PR((SCSI *scgp, struct disk *dp, struct dk_label *lp));
+LOCAL	void	chpart			__PR((struct disk *dp, struct dk_label *lp, int idx));
 #ifdef	SVR4
-LOCAL	int	prvttab		__PR((FILE *f, struct dk_label *lp, int i, int n));
+LOCAL	int	prvttab			__PR((FILE *f, struct dk_label *lp, int i, int n));
 #endif
-EXPORT	void	prpartab	__PR((FILE *f, char *disk_type, struct dk_label *lp));
-EXPORT	void	printlabel	__PR((struct dk_label *lp));
-LOCAL	void	printparthead	__PR((void));
-EXPORT	void	printpart	__PR((struct dk_label *lp, int i));
-LOCAL	void	_printpart	__PR((struct dk_label *lp, int i));
-EXPORT	void	printparts	__PR((struct dk_label *lp));
-EXPORT	int	readlabel	__PR((char *name, struct dk_label *lp));
-EXPORT	void	writelabel	__PR((char *name, struct dk_label *lp));
+EXPORT	void	prpartab		__PR((FILE *f, char *disk_type, struct dk_label *lp));
+EXPORT	void	printlabel		__PR((struct dk_label *lp));
+LOCAL	void	printparthead		__PR((void));
+EXPORT	void	printpart		__PR((struct dk_label *lp, int i));
+LOCAL	void	_printpart		__PR((struct dk_label *lp, int i));
+EXPORT	void	printparts		__PR((struct dk_label *lp));
+EXPORT	int	readlabel		__PR((char *name, struct dk_label *lp));
+EXPORT	void	writelabel		__PR((char *name, struct dk_label *lp));
 LOCAL	void	writebackuplabel	__PR((int f, struct dk_label *lp));
-EXPORT	int	setlabel	__PR((char *name, struct dk_label *lp));
-LOCAL	int	setgeom		__PR((int f, struct dk_label *lp));
-EXPORT	char	*getasciilabel	__PR((struct dk_label *lp));
-EXPORT	void	setasciilabel	__PR((struct dk_label *lp, char *lname));
-EXPORT	BOOL	setval_from_label __PR((struct disk *dp, struct dk_label *lp));
-EXPORT	void	label_null	__PR((struct dk_label *lp));
-EXPORT	int	label_cmp	__PR((struct dk_label *lp1, struct dk_label *lp2));
-EXPORT	BOOL	labelgeom_ok	__PR((struct dk_label *lp, BOOL print));
-LOCAL	void	lerror		__PR((struct dk_label *lp, char *name));
-LOCAL	void	tty_insert	__PR((char *s));
-LOCAL	long	getprevpart	__PR((void));
-LOCAL	long	getnextpart	__PR((void));
-EXPORT	BOOL	cvt_cyls	__PR((char *linep, long *lp, long mini, long maxi, struct disk *dp));
-EXPORT	BOOL	cvt_bcyls	__PR((char *linep, long *lp, long mini, long maxi, struct disk *dp));
+EXPORT	int	setlabel		__PR((char *name, struct dk_label *lp));
+LOCAL	int	setgeom			__PR((int f, struct dk_label *lp));
+EXPORT	char	*getasciilabel		__PR((struct dk_label *lp));
+EXPORT	void	setasciilabel		__PR((struct dk_label *lp, char *lname));
+EXPORT	BOOL	setval_from_label	__PR((struct disk *dp, struct dk_label *lp));
+EXPORT	void	label_null		__PR((struct dk_label *lp));
+EXPORT	int	label_cmp		__PR((struct dk_label *lp1, struct dk_label *lp2));
+EXPORT	BOOL	labelgeom_ok		__PR((struct dk_label *lp, BOOL print));
+LOCAL	void	lerror			__PR((struct dk_label *lp, char *name));
+LOCAL	void	tty_insert		__PR((char *s));
+LOCAL	long	getprevpart		__PR((void));
+LOCAL	long	getnextpart		__PR((void));
+EXPORT	BOOL	cvt_cyls		__PR((char *linep, long *lp, long mini, long maxi, struct disk *dp));
+EXPORT	BOOL	cvt_bcyls		__PR((char *linep, long *lp, long mini, long maxi, struct disk *dp));
 
 #ifdef	SVR4
 struct strval	vtags[] = {
@@ -213,7 +217,8 @@ BOOL check_vtmap(lp, set)
 }
 
 EXPORT
-void setlabel_from_val(dp, lp)
+void setlabel_from_val(scgp, dp, lp)
+	SCSI			*scgp;
 	struct disk		*dp;
 	register struct dk_label *lp;
 {
@@ -244,7 +249,7 @@ void setlabel_from_val(dp, lp)
 	if (dp->lncyl <= 0)	/* XXX kann spaeter weg */
 		raisecond("setlabel_from_val: lncyl", 0L);
 	if (dp->lpcyl <= 0 || dp->lpcyl > 0xFFFE)
-		get_lgeom_defaults(dp);
+		get_lgeom_defaults(scgp, dp);
 	lp->dkl_ncyl = dp->lncyl;
 	lp->dkl_acyl = dp->lacyl;
 	lp->dkl_pcyl = dp->lpcyl;
@@ -267,13 +272,14 @@ void setlabel_from_val(dp, lp)
 }
 
 EXPORT
-void makelabel(dp, lp)
+void makelabel(scgp, dp, lp)
+	SCSI			*scgp;
 	struct disk		*dp;
 	register struct dk_label *lp;
 {
 	char	lbuf[80];
 
-	setlabel_from_val(dp, lp);
+	setlabel_from_val(scgp, dp, lp);
 
 	if (yes("Label: <%s> change ? ", labelbuf)) {
 		printf("Enter disk label: "); flush();
@@ -645,7 +651,7 @@ void writebackuplabel(f, lp)
 	if (ioctl(f, DKIOCSAPART, &map) >= 0) {
 		for (i=1; i < 10; i += 2) {
 			if (lseek(f, (off_t)(512*(backup_label_blk + i)),
-								L_SET) < 0) {
+								SEEK_SET) < 0) {
 				errmsg("Seek error for backup label\n");
 				continue;
 			}
@@ -905,8 +911,10 @@ LOCAL
 void tty_insert(s)
 	char	*s;
 {
+#ifdef	TIOCSTI
 	while (*s)
 		ioctl (fdown(stdin), TIOCSTI, s++);
+#endif
 }
 
 
