@@ -1,7 +1,7 @@
-/* @(#)modes.c	1.23 97/03/02 Copyright 1988 J. Schilling */
+/* @(#)modes.c	1.35 00/07/30 Copyright 1988 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)modes.c	1.23 97/03/02 Copyright 1988 J. Schilling";
+	"@(#)modes.c	1.35 00/07/30 Copyright 1988 J. Schilling";
 #endif
 /*
  *	Handle SCSI mode pages
@@ -24,41 +24,47 @@ static	char sccsid[] =
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <mconfig.h>
+#include <stdio.h>
 #include <sys/types.h>
 
 #include <sys/time.h>
 #include <sys/ioctl.h>
 
 #include <standard.h>
+#include <schily.h>
 
-#include "scgio.h"
+#include <scg/scgcmd.h>
+#include <scg/scsireg.h>
+#include <scg/scsidefs.h>
+#include <scg/scsitransp.h>
 
-#include "fmt.h"
-#include "scsireg.h"
-#include "scsidefs.h"
 #include "scsicmds.h"
+#include "fmt.h"
 
 extern	int	debug;
 
-extern	int	silent;
-extern	int	verbose;
 extern	int	force;
 extern	int	save_mp;
 extern	int	defmodes;
 extern	int	scsi_compliant;
 
-extern	struct scg_cmd	scmd;
-extern	struct scsi_inquiry inq;
-
-LOCAL	BOOL	has_mode_page	__PR((int, char *, int *));
-LOCAL	void	get_secsize	__PR((struct disk *, u_char *));
-LOCAL	void	get_capacity	__PR((struct disk *, u_char *));
-LOCAL	BOOL	get_format_defaults __PR((struct disk *));
-LOCAL	BOOL	get_geom_defaults __PR((struct disk *));
-LOCAL	BOOL	get_common_control_defaults __PR((struct disk *));
+LOCAL	BOOL	has_mode_page			__PR((SCSI *scgp, int, char *, int *));
+EXPORT	BOOL	get_mode_params			__PR((SCSI *scgp, int page, char *pagename,
+							u_char *modep, u_char *cmodep, u_char *dmodep, u_char *smodep,
+							int *lenp));
+EXPORT	BOOL	set_mode_params			__PR((SCSI *scgp, char *, u_char *, int, int,
+							struct disk *));
+EXPORT	BOOL	set_error_rec_params		__PR((SCSI *scgp, struct disk *));
+LOCAL	void	get_secsize			__PR((struct disk *, u_char *));
+LOCAL	void	get_capacity			__PR((struct disk *, u_char *));
+LOCAL	BOOL	get_format_defaults		__PR((SCSI *scgp, struct disk *));
+LOCAL	BOOL	get_geom_defaults		__PR((SCSI *scgp, struct disk *));
+LOCAL	BOOL	get_common_control_defaults	__PR((SCSI *scgp, struct disk *));
 
 LOCAL
-BOOL has_mode_page(page, pagename, lenp)
+BOOL has_mode_page(scgp, page, pagename, lenp)
+	SCSI	*scgp;
 	int	page;
 	char	*pagename;
 	int	*lenp;
@@ -73,27 +79,27 @@ again:
 	if (lenp)
 		*lenp = 0;
 
-	(void)test_unit_ready();
-	silent++;
+	(void)test_unit_ready(scgp);
+	scgp->silent++;
 /* Maxoptix bringt Aborted cmd 0x0B mit code 0x4E (overlapping cmds)*/
-	if (mode_sense(mode, len, page, 2) < 0) {	/* Page n default */
-		silent--;
+	if (mode_sense(scgp, mode, len, page, 2) < 0) {	/* Page n default */
+		scgp->silent--;
 		return (FALSE);
 	} else {
 		len = ((struct scsi_mode_header *)mode)->sense_data_len + 1;
 	}
-	if (mode_sense(mode, len, page, 2) < 0) {	/* Page n default */
-		silent--;
+	if (mode_sense(scgp, mode, len, page, 2) < 0) {	/* Page n default */
+		scgp->silent--;
 		return (FALSE);
 	}
-	silent--;
+	scgp->silent--;
 
-	if (verbose)
-		prbytes("Mode Sense Data", mode, len - scmd.resid);
+	if (scgp->verbose)
+		prbytes("Mode Sense Data", mode, len - scg_getresid(scgp));
 	mp = (struct scsi_mode_page_header *)
 		(mode + sizeof(struct scsi_mode_header) +
 		((struct scsi_mode_header *)mode)->blockdesc_len);
-	if (verbose)
+	if (scgp->verbose)
 		prbytes("Mode Sense Data", (u_char *)mp, mp->p_len+2);
 
 	if (mp->p_len == 0) {
@@ -122,7 +128,8 @@ again:
 }
 
 EXPORT
-BOOL get_mode_params(page, pagename, modep, cmodep, dmodep, smodep, lenp)
+BOOL get_mode_params(scgp, page, pagename, modep, cmodep, dmodep, smodep, lenp)
+	SCSI	*scgp;
 	int	page;
 	char	*pagename;
 	u_char	*modep;
@@ -136,8 +143,8 @@ BOOL get_mode_params(page, pagename, modep, cmodep, dmodep, smodep, lenp)
 
 	if (lenp)
 		*lenp = 0;
-	if (!has_mode_page(page, pagename, &len)) {
-		if (!silent) errmsgno(EX_BAD,
+	if (!has_mode_page(scgp, page, pagename, &len)) {
+		if (!scgp->silent) errmsgno(EX_BAD,
 			"Warning: controller does not support %s page.\n",
 								pagename);
 		return (TRUE);	/* Hoffentlich klappt's trotzdem */
@@ -147,42 +154,42 @@ BOOL get_mode_params(page, pagename, modep, cmodep, dmodep, smodep, lenp)
 
 	if (modep) {
 		fillbytes(modep, 0x100, '\0');
-		if (mode_sense(modep, len, page, 0) < 0) {/* Page x current */
+		if (mode_sense(scgp, modep, len, page, 0) < 0) {/* Page x current */
 			errmsgno(EX_BAD, "Cannot get %s data.\n", pagename);
 			ret = FALSE;
-		} else if (verbose) {
-			prbytes("Mode Sense Data", modep, len - scmd.resid);
+		} else if (scgp->verbose) {
+			prbytes("Mode Sense Data", modep, len - scg_getresid(scgp));
 		}
 	}
 
 	if (cmodep) {
 		fillbytes(cmodep, 0x100, '\0');
-		if (mode_sense(cmodep, len, page, 1) < 0) {/* Page x change */
+		if (mode_sense(scgp, cmodep, len, page, 1) < 0) {/* Page x change */
 			errmsgno(EX_BAD, "Cannot get %s mask.\n", pagename);
 			ret = FALSE;
-		} else if (verbose) {
-			prbytes("Mode Sense Data", cmodep, len - scmd.resid);
+		} else if (scgp->verbose) {
+			prbytes("Mode Sense Data", cmodep, len - scg_getresid(scgp));
 		}
 	}
 
 	if (dmodep) {
 		fillbytes(dmodep, 0x100, '\0');
-		if (mode_sense(dmodep, len, page, 2) < 0) {/* Page x default */
+		if (mode_sense(scgp, dmodep, len, page, 2) < 0) {/* Page x default */
 			errmsgno(EX_BAD, "Cannot get default %s data.\n",
 								pagename);
 			ret = FALSE;
-		} else if (verbose) {
-			prbytes("Mode Sense Data", dmodep, len - scmd.resid);
+		} else if (scgp->verbose) {
+			prbytes("Mode Sense Data", dmodep, len - scg_getresid(scgp));
 		}
 	}
 
 	if (smodep) {
 		fillbytes(smodep, 0x100, '\0');
-		if (mode_sense(smodep, len, page, 3) < 0) {/* Page x saved */
+		if (mode_sense(scgp, smodep, len, page, 3) < 0) {/* Page x saved */
 			errmsgno(EX_BAD, "Cannot get saved %s data.\n", pagename);
 			ret = FALSE;
-		} else if (verbose) {
-			prbytes("Mode Sense Data", smodep, len - scmd.resid);
+		} else if (scgp->verbose) {
+			prbytes("Mode Sense Data", smodep, len - scg_getresid(scgp));
 		}
 	}
 
@@ -190,7 +197,8 @@ BOOL get_mode_params(page, pagename, modep, cmodep, dmodep, smodep, lenp)
 }
 
 EXPORT
-BOOL set_mode_params(pagename, modep, len, save, dp)
+BOOL set_mode_params(scgp, pagename, modep, len, save, dp)
+	SCSI	*scgp;
 	char	*pagename;
 	u_char	*modep;
 	int	len;
@@ -211,8 +219,8 @@ BOOL set_mode_params(pagename, modep, len, save, dp)
 							dp->secsize);
 	}
 
-	if (mode_select(modep, len, save, inq.ansi_version >= 2) < 0) {
-		if (mode_select(modep, len, 0, inq.ansi_version >= 2) < 0) {
+	if (mode_select(scgp, modep, len, save, scgp->inq->ansi_version >= 2) < 0) {
+		if (mode_select(scgp, modep, len, 0, scgp->inq->ansi_version >= 2) < 0) {
 			errmsgno(EX_BAD,
 			   "Warning: using default %s data.\n", pagename);
 		}
@@ -221,7 +229,8 @@ BOOL set_mode_params(pagename, modep, len, save, dp)
 }
 
 EXPORT
-BOOL set_error_rec_params(dp)
+BOOL set_error_rec_params(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -234,7 +243,7 @@ BOOL set_error_rec_params(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
-	if (!get_mode_params(1, "error recovery parameter",
+	if (!get_mode_params(scgp, 1, "error recovery parameter",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -261,14 +270,15 @@ BOOL set_error_rec_params(dp)
 		mp->wr_retry_count = dp->wr_retry_count;
 
 	if (dp->recov_timelim >= 0
-				&& a_to_u_short(cmp->recov_timelim) != 0)
-		i_to_short(mp->recov_timelim, dp->recov_timelim);
+				&& a_to_u_2_byte(cmp->recov_timelim) != 0)
+		i_to_2_byte(mp->recov_timelim, dp->recov_timelim);
 
-	return (set_mode_params("error recovery parameter", mode, len, mp_save, dp));
+	return (set_mode_params(scgp, "error recovery parameter", mode, len, mp_save, dp));
 }
 
 EXPORT
-BOOL set_disre_params(dp)
+BOOL set_disre_params(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -281,7 +291,7 @@ BOOL set_disre_params(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
-	if (!get_mode_params(2, "disre parameter",
+	if (!get_mode_params(scgp, 2, "disre parameter",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -303,35 +313,36 @@ BOOL set_disre_params(dp)
 		mp->buf_empt_ratio = dp->buf_empt_ratio;
 
 	if (dp->bus_inact_limit >= 0
-				&& a_to_u_short(cmp->bus_inact_limit) != 0)
-		i_to_short(mp->bus_inact_limit, dp->bus_inact_limit);
+				&& a_to_u_2_byte(cmp->bus_inact_limit) != 0)
+		i_to_2_byte(mp->bus_inact_limit, dp->bus_inact_limit);
 
 	if (dp->disc_time_limit >= 0
-				&& a_to_u_short(cmp->disc_time_limit) != 0)
-		i_to_short(mp->disc_time_limit, dp->disc_time_limit);
+				&& a_to_u_2_byte(cmp->disc_time_limit) != 0)
+		i_to_2_byte(mp->disc_time_limit, dp->disc_time_limit);
 
 	if (dp->conn_time_limit >= 0
-				&& a_to_u_short(cmp->conn_time_limit) != 0)
-		i_to_short(mp->conn_time_limit, dp->conn_time_limit);
+				&& a_to_u_2_byte(cmp->conn_time_limit) != 0)
+		i_to_2_byte(mp->conn_time_limit, dp->conn_time_limit);
 
 	if (dp->max_burst_size >= 0
-				&& a_to_u_short(cmp->max_burst_size) != 0)
-		i_to_short(mp->max_burst_size, dp->max_burst_size);
+				&& a_to_u_2_byte(cmp->max_burst_size) != 0)
+		i_to_2_byte(mp->max_burst_size, dp->max_burst_size);
 
 	if (dp->data_tr_dis_ctl >= 0 && cmp->data_tr_dis_ctl != 0)
 		mp->data_tr_dis_ctl = dp->data_tr_dis_ctl;
 
 #ifdef	OLD
 /*XXX*/						/* 4.0 ms max Connect time */
-	if (a_to_u_short(cmp->bus_inact_limit) != 0)
-		i_to_short(mp->bus_inact_limit, 40);
+	if (a_to_u_2_byte(cmp->bus_inact_limit) != 0)
+		i_to_2_byte(mp->bus_inact_limit, 40);
 #endif
 
-	return (set_mode_params("disre parameter", mode, len, mp_save, dp));
+	return (set_mode_params(scgp, "disre parameter", mode, len, mp_save, dp));
 }
 
 EXPORT
-BOOL set_format_params(dp)
+BOOL set_format_params(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -345,7 +356,7 @@ BOOL set_format_params(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
-	if (!get_mode_params(3, "format parameter",
+	if (!get_mode_params(scgp, 3, "format parameter",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -367,27 +378,27 @@ BOOL set_format_params(dp)
 	mp_save = save_mp && mp->parsave;
 	mp->parsave = 0;
 
-	if (a_to_u_short(cmp->trk_per_zone) != 0)
-		i_to_short(mp->trk_per_zone, dp->tpz);
+	if (a_to_u_2_byte(cmp->trk_per_zone) != 0)
+		i_to_2_byte(mp->trk_per_zone, dp->tpz);
 
-	if (a_to_u_short(cmp->alt_sec_per_zone) != 0)
-		i_to_short(mp->alt_sec_per_zone, dp->aspz);
+	if (a_to_u_2_byte(cmp->alt_sec_per_zone) != 0)
+		i_to_2_byte(mp->alt_sec_per_zone, dp->aspz);
 
-	if (a_to_u_short(cmp->alt_trk_per_vol) != 0)
-		i_to_short(mp->alt_trk_per_vol, dp->atrk);
+	if (a_to_u_2_byte(cmp->alt_trk_per_vol) != 0)
+		i_to_2_byte(mp->alt_trk_per_vol, dp->atrk);
 
-	if (a_to_u_short(cmp->sect_per_trk) != 0)
-		i_to_short(mp->sect_per_trk, dp->spt);
+	if (a_to_u_2_byte(cmp->sect_per_trk) != 0)
+		i_to_2_byte(mp->sect_per_trk, dp->spt);
 
-	if (a_to_u_short(cmp->bytes_per_phys_sect) != 0 && 
+	if (a_to_u_2_byte(cmp->bytes_per_phys_sect) != 0 && 
 						dp->phys_secsize > 0)
-		i_to_short(mp->bytes_per_phys_sect, dp->phys_secsize);
+		i_to_2_byte(mp->bytes_per_phys_sect, dp->phys_secsize);
 
-	if (a_to_u_short(cmp->trk_skew) != 0)
-		i_to_short(mp->trk_skew, dp->track_skew);
+	if (a_to_u_2_byte(cmp->trk_skew) != 0)
+		i_to_2_byte(mp->trk_skew, dp->track_skew);
 
-	if (a_to_u_short(cmp->cyl_skew) != 0)
-		i_to_short(mp->cyl_skew, dp->cyl_skew);
+	if (a_to_u_2_byte(cmp->cyl_skew) != 0)
+		i_to_2_byte(mp->cyl_skew, dp->cyl_skew);
 
 #ifdef	OLD
 	/*
@@ -400,17 +411,18 @@ BOOL set_format_params(dp)
 	mp = (struct scsi_mode_page_03 *)
 		(cmode + sizeof(struct scsi_mode_header) +
 		((struct scsi_mode_header *)cmode)->blockdesc_len);
-	if (a_to_u_short(mp->sect_per_trk) == 0)
-		i_to_short(mp->sect_per_trk, dp->spt);
-	if (a_to_u_short(mp->bytes_per_phys_sect) == 0)
-		i_to_short(mp->bytes_per_phys_sect, dp->secsize);
+	if (a_to_u_2_byte(mp->sect_per_trk) == 0)
+		i_to_2_byte(mp->sect_per_trk, dp->spt);
+	if (a_to_u_2_byte(mp->bytes_per_phys_sect) == 0)
+		i_to_2_byte(mp->bytes_per_phys_sect, dp->secsize);
 #endif
 
-	return (set_mode_params("format parameter", mode, len, mp_save, dp));
+	return (set_mode_params(scgp, "format parameter", mode, len, mp_save, dp));
 }
 
 EXPORT
-BOOL set_geom(dp)
+BOOL set_geom(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -423,7 +435,7 @@ BOOL set_geom(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
-	if (!get_mode_params(4, "geometry",
+	if (!get_mode_params(scgp, 4, "geometry",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -438,7 +450,7 @@ BOOL set_geom(dp)
 	mp_save = save_mp && mp->parsave;
 	mp->parsave = 0;
 
-	if (a_to_3_byte(cmp->ncyl) != 0)
+	if (a_to_u_3_byte(cmp->ncyl) != 0)
 		i_to_3_byte(mp->ncyl, dp->pcyl);
 
 	if (cmp->nhead != 0)
@@ -450,11 +462,12 @@ BOOL set_geom(dp)
 	if (cmp->rotational_off != 0)
 		mp->rotational_off = dp->rotational_off;
 
-	return (set_mode_params("geometry", mode, len, mp_save, dp));
+	return (set_mode_params(scgp, "geometry", mode, len, mp_save, dp));
 }
 
 EXPORT
-BOOL set_common_control(dp)
+BOOL set_common_control(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -467,7 +480,7 @@ BOOL set_common_control(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
-	if (!get_mode_params(0xA, "common device control",
+	if (!get_mode_params(scgp, 0xA, "common device control",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -493,24 +506,23 @@ BOOL set_common_control(dp)
 
 
 EXPORT
-void get_mode_defaults(dp)
+void get_mode_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
-	extern struct scsi_capacity cap;
-
-	get_error_rec_defaults(dp);
-	get_disre_defaults(dp);
-	get_geom_defaults(dp);/* nhead wird in set_format_defaults gebraucht */
-	get_format_defaults(dp);
+	get_error_rec_defaults(scgp, dp);
+	get_disre_defaults(scgp, dp);
+	get_geom_defaults(scgp, dp);/* nhead wird in set_format_defaults gebraucht */
+	get_format_defaults(scgp, dp);
 	if (dp->secsize < 0) {
-		if (read_capacity() < 0)
+		if (read_capacity(scgp) < 0)
 			return;
-		if (cap.c_bsize > 0)
-			dp->secsize = cap.c_bsize;
+		if (scgp->cap->c_bsize > 0)
+			dp->secsize = scgp->cap->c_bsize;
 	}
-	silent++;
-	get_common_control_defaults(dp);
-	silent--;
+	scgp->silent++;
+	get_common_control_defaults(scgp, dp);
+	scgp->silent--;
 }
 
 LOCAL
@@ -522,7 +534,7 @@ void get_secsize(dp, modep)
 
 	if (dp->secsize < 0 &&
 			((struct scsi_mode_header *)modep)->blockdesc_len) {
-		tmp = a_to_3_byte(((struct scsi_mode_data *)modep)->
+		tmp = a_to_u_3_byte(((struct scsi_mode_data *)modep)->
 							blockdesc.lblen);
 		if (tmp != 0)
 			dp->secsize = tmp;
@@ -538,7 +550,7 @@ void get_capacity(dp, modep)
 
 	if (dp->capacity < 0 &&
 			((struct scsi_mode_header *)modep)->blockdesc_len) {
-		tmp = a_to_3_byte(((struct scsi_mode_data *)modep)->
+		tmp = a_to_u_3_byte(((struct scsi_mode_data *)modep)->
 							blockdesc.nlblock);
 		if (tmp != 0)
 			dp->capacity = tmp;
@@ -546,7 +558,8 @@ void get_capacity(dp, modep)
 }
 
 EXPORT
-BOOL get_error_rec_defaults(dp)
+BOOL get_error_rec_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -561,10 +574,10 @@ BOOL get_error_rec_defaults(dp)
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
 	if (defmodes == 0 && dp->formatted > 0 &&
-		get_mode_params(1, "error recovery parameter",
+		get_mode_params(scgp, 1, "error recovery parameter",
 				mode, cmode, (u_char *)0, (u_char *)0, &len))
 		;
-	else if (!get_mode_params(1, "error recovery parameter",
+	else if (!get_mode_params(scgp, 1, "error recovery parameter",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -586,8 +599,8 @@ BOOL get_error_rec_defaults(dp)
 	if (dp->wr_retry_count < 0 && cmp->wr_retry_count != 0)
 		dp->wr_retry_count = mp->wr_retry_count;
 
-	tmp  = a_to_u_short(mp->recov_timelim);
-	ctmp = a_to_u_short(cmp->recov_timelim);
+	tmp  = a_to_u_2_byte(mp->recov_timelim);
+	ctmp = a_to_u_2_byte(cmp->recov_timelim);
 	if (dp->recov_timelim < 0 && ctmp != 0)
 		dp->recov_timelim = tmp;
 
@@ -595,7 +608,8 @@ BOOL get_error_rec_defaults(dp)
 }
 
 EXPORT
-BOOL get_disre_defaults(dp)
+BOOL get_disre_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -610,10 +624,10 @@ BOOL get_disre_defaults(dp)
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
 	if (defmodes == 0 && dp->formatted > 0 &&
-		get_mode_params(2, "disre parameter",
+		get_mode_params(scgp, 2, "disre parameter",
 				mode, cmode, (u_char *)0, (u_char *)0, &len))
 		;
-	else if (!get_mode_params(2, "disre parameter",
+	else if (!get_mode_params(scgp, 2, "disre parameter",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -635,23 +649,23 @@ BOOL get_disre_defaults(dp)
 	if (dp->buf_empt_ratio < 0 && cmp->buf_empt_ratio != 0)
 		dp->buf_empt_ratio = mp->buf_empt_ratio;
 
-	tmp  = a_to_u_short(mp->bus_inact_limit);
-	ctmp = a_to_u_short(cmp->bus_inact_limit);
+	tmp  = a_to_u_2_byte(mp->bus_inact_limit);
+	ctmp = a_to_u_2_byte(cmp->bus_inact_limit);
 	if (dp->bus_inact_limit < 0 && ctmp != 0)
 		dp->bus_inact_limit = tmp;
 
-	tmp  = a_to_u_short(mp->disc_time_limit);
-	ctmp = a_to_u_short(cmp->disc_time_limit);
+	tmp  = a_to_u_2_byte(mp->disc_time_limit);
+	ctmp = a_to_u_2_byte(cmp->disc_time_limit);
 	if (dp->disc_time_limit < 0 && ctmp != 0)
 		dp->disc_time_limit = tmp;
 
-	tmp  = a_to_u_short(mp->conn_time_limit);
-	ctmp = a_to_u_short(cmp->conn_time_limit);
+	tmp  = a_to_u_2_byte(mp->conn_time_limit);
+	ctmp = a_to_u_2_byte(cmp->conn_time_limit);
 	if (dp->conn_time_limit < 0 && ctmp != 0)
 		dp->conn_time_limit = tmp;
 
-	tmp  = a_to_u_short(mp->max_burst_size);
-	ctmp = a_to_u_short(cmp->max_burst_size);
+	tmp  = a_to_u_2_byte(mp->max_burst_size);
+	ctmp = a_to_u_2_byte(cmp->max_burst_size);
 	if (dp->max_burst_size < 0 && ctmp != 0)
 		dp->max_burst_size = tmp;
 
@@ -662,7 +676,8 @@ BOOL get_disre_defaults(dp)
 }
 
 LOCAL
-BOOL get_format_defaults(dp)
+BOOL get_format_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -676,10 +691,10 @@ BOOL get_format_defaults(dp)
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
 	if (defmodes == 0 && dp->formatted > 0 &&
-		get_mode_params(3, "format parameter",
+		get_mode_params(scgp, 3, "format parameter",
 				mode, cmode, (u_char *)0, (u_char *)0, &len))
 		;
-	else if (!get_mode_params(3, "format parameter",
+	else if (!get_mode_params(scgp, 3, "format parameter",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -695,10 +710,10 @@ BOOL get_format_defaults(dp)
 	get_secsize(dp, mode);
 	get_capacity(dp, mode);
 
-	tmp = a_to_u_short(mp->trk_per_zone);
+	tmp = a_to_u_2_byte(mp->trk_per_zone);
 	if (dp->tpz < 0)
 		dp->tpz = tmp;
-	tmp = a_to_u_short(cmp->trk_per_zone);
+	tmp = a_to_u_2_byte(cmp->trk_per_zone);
 	if (dp->tpz < 0 || tmp != 0) {
 		dp->mintpz = 0;
 		dp->maxtpz = 0xFFFF;
@@ -706,21 +721,21 @@ BOOL get_format_defaults(dp)
 		dp->mintpz = dp->maxtpz = dp->tpz;
 	}
 
-	tmp = a_to_u_short(mp->alt_sec_per_zone);
+	tmp = a_to_u_2_byte(mp->alt_sec_per_zone);
 	if (dp->aspz < 0)
 		dp->aspz = tmp;
 
-	tmp = a_to_u_short(mp->alt_trk_per_vol);
+	tmp = a_to_u_2_byte(mp->alt_trk_per_vol);
 	if (dp->atrk < 0)
 		dp->atrk = tmp;
 
-	tmp = a_to_u_short(mp->sect_per_trk);
+	tmp = a_to_u_2_byte(mp->sect_per_trk);
 	if (dp->spt < 0 && tmp != 0)
 		dp->spt = tmp;
 
-	tmp = a_to_u_short(mp->bytes_per_phys_sect);
+	tmp = a_to_u_2_byte(mp->bytes_per_phys_sect);
 	if (dp->phys_secsize < 0 && tmp != 0) {
-		long ctmp = a_to_u_short(cmp->bytes_per_phys_sect);
+		long ctmp = a_to_u_2_byte(cmp->bytes_per_phys_sect);
 
 		if (ctmp != 0)
 			dp->phys_secsize = tmp;
@@ -729,15 +744,15 @@ BOOL get_format_defaults(dp)
 							tmp, ctmp, ctmp);
 	}
 
-	tmp = a_to_u_short(mp->interleave);
+	tmp = a_to_u_2_byte(mp->interleave);
 	if (dp->interleave < 0)
 		dp->interleave = tmp;
 
-	tmp = a_to_u_short(mp->trk_skew);
+	tmp = a_to_u_2_byte(mp->trk_skew);
 	if (dp->track_skew < 0)
 		dp->track_skew = tmp;
 
-	tmp = a_to_u_short(mp->cyl_skew);
+	tmp = a_to_u_2_byte(mp->cyl_skew);
 	if (dp->cyl_skew < 0)
 		dp->cyl_skew = tmp;
 
@@ -745,7 +760,8 @@ BOOL get_format_defaults(dp)
 }
 
 LOCAL
-BOOL get_geom_defaults(dp)
+BOOL get_geom_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -756,10 +772,10 @@ BOOL get_geom_defaults(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 
 	if (defmodes == 0 && dp->formatted > 0 &&
-		get_mode_params(4, "geometry",
+		get_mode_params(scgp, 4, "geometry",
 			mode, (u_char *)0, (u_char *)0, (u_char *)0, &len))
 		;
-	else if (!get_mode_params(4, "geometry",
+	else if (!get_mode_params(scgp, 4, "geometry",
 			(u_char *)0, (u_char *)0, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -772,14 +788,14 @@ BOOL get_geom_defaults(dp)
 	get_secsize(dp, mode);
 	get_capacity(dp, mode);
 
-	tmp = a_to_3_byte(mp->ncyl);
+	tmp = a_to_u_3_byte(mp->ncyl);
 	if (dp->pcyl < 0 && tmp != 0)
 		dp->pcyl = tmp;
 
 	if (dp->nhead < 0 && mp->nhead != 0)
 		dp->nhead = mp->nhead;
 
-	tmp = a_to_u_short(mp->rotation_rate);
+	tmp = a_to_u_2_byte(mp->rotation_rate);
 	if (dp->rpm < 0 && tmp != 0)
 		dp->rpm = tmp;
 
@@ -795,7 +811,8 @@ BOOL get_geom_defaults(dp)
 }
 
 LOCAL
-BOOL get_common_control_defaults(dp)
+BOOL get_common_control_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -805,10 +822,10 @@ BOOL get_common_control_defaults(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 
 	if (defmodes == 0 && dp->formatted > 0 &&
-		get_mode_params(0xA, "common device control",
+		get_mode_params(scgp, 0xA, "common device control",
 			mode, (u_char *)0, (u_char *)0, (u_char *)0, &len))
 		;
-	else if (!get_mode_params(0xA, "common device control",
+	else if (!get_mode_params(scgp, 0xA, "common device control",
 			(u_char *)0, (u_char *)0, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -826,7 +843,8 @@ BOOL get_common_control_defaults(dp)
 
 
 EXPORT
-BOOL get_sony_format_defaults(dp)
+BOOL get_sony_format_defaults(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -837,10 +855,10 @@ BOOL get_sony_format_defaults(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 
 	if (defmodes == 0 && dp->formatted > 0 &&
-		get_mode_params(0x20, "sony format",
+		get_mode_params(scgp, 0x20, "sony format",
 			mode, (u_char *)0, (u_char *)0, (u_char *)0, &len))
 		;
-	else if (!get_mode_params(0x20, "sony format",
+	else if (!get_mode_params(scgp, 0x20, "sony format",
 			(u_char *)0, (u_char *)0, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -856,7 +874,7 @@ BOOL get_sony_format_defaults(dp)
 	if (dp->fmt_mode < 0)
 		dp->fmt_mode = mp->format_mode;
 
-	tmp = a_to_u_short(mp->spare_band_size);
+	tmp = a_to_u_2_byte(mp->spare_band_size);
 	if (dp->fmt_mode > 1 && dp->spare_band_size < 0)
 		dp->spare_band_size = tmp;
 
@@ -866,7 +884,8 @@ printf("mode: %d spare_band: %ld\n", mp->format_mode, tmp);
 }
 
 EXPORT
-BOOL set_sony_params(dp)
+BOOL set_sony_params(scgp, dp)
+	SCSI		*scgp;
 	struct disk	*dp;
 {
 	u_char	mode[0x100];
@@ -882,7 +901,7 @@ BOOL set_sony_params(dp)
 	fillbytes((caddr_t)mode, sizeof(mode), '\0');
 	fillbytes((caddr_t)cmode, sizeof(cmode), '\0');
 
-	if (!get_mode_params(0x20, "sony format",
+	if (!get_mode_params(scgp, 0x20, "sony format",
 				(u_char *)0, cmode, mode, (u_char *)0, &len))
 		return (FALSE);
 	if (len == 0)
@@ -907,19 +926,19 @@ BOOL set_sony_params(dp)
 									'\0');
 	} else {
 		mp->format_type = 1;
-		i_to_long(mp->num_bands, 1);
+		i_to_4_byte(mp->num_bands, 1);
 #ifdef	OLD
 		{ int t;				/*XXX aspt ??? */
 			t = dp->spt;
 			if (dp->tpz != 0)
 				t -= dp->aspz/dp->tpz;
 			t *= dp->atrk;
-			i_to_short(mp->spare_band_size, t);
+			i_to_2_byte(mp->spare_band_size, t);
 		}
 #else
-		i_to_short(mp->spare_band_size, dp->spare_band_size);
+		i_to_2_byte(mp->spare_band_size, dp->spare_band_size);
 #endif
 	}
 
-	return (set_mode_params("sony format", mode, len, mp_save, dp));
+	return (set_mode_params(scgp, "sony format", mode, len, mp_save, dp));
 }
