@@ -1,7 +1,7 @@
-/* @(#)xdisk.c	1.21 98/06/01 Copyright 1991 J. Schilling */
+/* @(#)xdisk.c	1.27 00/05/07 Copyright 1991 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)xdisk.c	1.21 98/06/01 Copyright 1991 J. Schilling";
+	"@(#)xdisk.c	1.27 00/05/07 Copyright 1991 J. Schilling";
 #endif
 /*
  *	Routines to handle external disk definitions
@@ -24,10 +24,12 @@ static	char sccsid[] =
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <mconfig.h>
 #include <stdio.h>
 #include <standard.h>
 #include <stdxlib.h>
-#include <string.h>
+#include <strdefs.h>
+#include <schily.h>
 #include <sys/types.h>
 #ifdef	HAVE_STDC_HEADERS
 #	include <stddef.h>
@@ -36,7 +38,9 @@ static	char sccsid[] =
 #	include <struct.h>
 #	define	soff(str, fld)	fldoff(str, fld)
 #endif
-#include <scsireg.h>
+#include <scg/scsireg.h>
+#include <scg/scsitransp.h>
+
 #include "fmt.h"
 
 #ifdef	FMT
@@ -47,7 +51,6 @@ extern	int	autoformat;
 #else
 	int	xdebug = 1;
 #endif
-extern struct	scsi_inquiry inq;
 
 struct  dsk_fnd {
 	struct disk	disk;
@@ -61,8 +64,8 @@ EXPORT	BOOL	pdisk_eql	__PR((struct disk *dp1, struct disk *dp2));
 LOCAL	BOOL	add_disk	__PR((char *, struct disk *, struct dsk_fnd *));
 LOCAL	void	check_deflt	__PR((struct dsk_fnd *, int *, int));
 LOCAL	void	use_disk	__PR((struct disk *, struct dsk_fnd *, int));
-LOCAL	void	select_disk	__PR((struct disk *, struct dsk_fnd *, int, int));
-EXPORT	BOOL	get_ext_diskdata __PR((char *name, struct disk *dp));
+LOCAL	void	select_disk	__PR((SCSI *scgp, struct disk *, struct dsk_fnd *, int, int));
+EXPORT	BOOL	get_ext_diskdata __PR((SCSI *scgp, char *name, struct disk *dp));
 LOCAL	int	do_disk		__PR((char *, struct disk *, BOOL));
 LOCAL	void	set_diskitem	__PR((struct disk *, char *, char *, char *));
 LOCAL	BOOL	set_diskvar	__PR((char *, struct disk *));
@@ -323,7 +326,8 @@ LOCAL void use_disk(dp, df, this)
 
 #define	item_equal(a, b)	(((a) <  0 && (b) <  0) || ((a) == (b)))
 
-LOCAL void select_disk(dp, df, found, deflt)
+LOCAL void select_disk(scgp, dp, df, found, deflt)
+	SCSI		*scgp;
 	struct disk	*dp;
 	struct dsk_fnd	*df;
 	int		found;
@@ -361,7 +365,7 @@ LOCAL void select_disk(dp, df, found, deflt)
 		copy_disk(dp, &df[this].disk);
 		df[this].disk.flags |= D_DISK_CURRENT;
 		df[this].match = cmp_disk(dp, &df[this].disk);
-		copy_vendor_info(df[this].name, &inq);
+		copy_vendor_info(df[this].name, scgp->inq);
 		found++;
 	}
 	/*
@@ -431,7 +435,7 @@ LOCAL void select_disk(dp, df, found, deflt)
 		use_disk(dp, df, this);
 
 		if(found > 1 && selected)
-			prdisk(stdout, dp, &inq);
+			prdisk(stdout, dp, scgp->inq);
 
 	} while(selected && found > 1 && !yes("Use this disk parameters? "));
 
@@ -453,7 +457,8 @@ LOCAL void select_disk(dp, df, found, deflt)
 }
 
 EXPORT
-BOOL get_ext_diskdata(name, dp)
+BOOL get_ext_diskdata(scgp, name, dp)
+	SCSI		*scgp;
 	char		*name;
 	struct disk	*dp;
 {
@@ -539,7 +544,7 @@ again:
 		if (autoformat ||
 			!yes("Ignore database disk parameters from '%s'? ",
 							datfilename())) {
-			select_disk(dp, disks_found, found, deflt);
+			select_disk(scgp, dp, disks_found, found, deflt);
 			free(disks_found);
 			return (TRUE);
 		}
